<?php
/**
*	@file admin_index_form_handling.php
*	@brief A file to handle forms in administrator index.php.
*/

/** An array to hold possible errors in submitted form. */
$form_errors = array();

/**
* Function to process admin index forms.
* Processes admin index forms according to $_POST variable and stores possible errors to #$form_errors.
* @return void
*/
function process_admin_index_forms() {
	
	global $form_errors;
	// Boolean to check if form contains errors
	$error = false;
	/** FormHandler $form_handler For validating and sanitizing the data. */
	$form_handler = new FormHandler();
	/** array $form_data An array to hold processed form data. */
	$form_data = array();
	
	// Create new game form is submitted
	if (isset($_POST['admin_index_form_create'])){
		
		if (isset($_SESSION['admin']['new_game'])) {
			unset($_SESSION['admin']['new_game']);
		}
		if (isset($_SESSION['admin']['open_game'])) {
			unset($_SESSION['admin']['open_game']);
		}
		$form_data['new_game'] = array();
		$form_errors['admin']['new_game'] = array();
		
		if (isset($_POST['admin']['new_game']['game_name'])) {
			
			$data = $form_handler->SanitizeString($_POST['admin']['new_game']['game_name'], GAME_NAME_MAX_LENGTH, true, GAME_NAME_MIN_LENGTH);
			
			if (!$data) {
				$error = true;
				$form_errors['admin']['new_game']['game_name'] = $form_handler->_latest_error;
			}
			else {
				$form_data['new_game']['game_name'] = $data;
			}
		}
		if (isset($_POST['admin']['new_game']['admin_username'])) {
			
			$data = $form_handler->SanitizeString($_POST['admin']['new_game']['admin_username'], USERNAME_MAX_LENGTH, false, USERNAME_MIN_LENGTH);
			
			if (!$data) {
				$error = true;
				$form_errors['admin']['new_game']['admin_username'] = $form_handler->_latest_error;
			}
			else {
				$form_data['new_game']['admin_username'] = $data;
			}
		}
		if (isset($_POST['admin']['new_game']['admin_password'])) {
			
			$data = $form_handler->SanitizeString($_POST['admin']['new_game']['admin_password'], PASSWORD_MAX_LENGTH, false, PASSWORD_MIN_LENGTH);
			
			if (!$data) {
				$error = true;
				$form_errors['admin']['new_game']['admin_password'] = $form_handler->_latest_error;
			}
			else {
				$form_data['new_game']['admin_password'] = $data;
			}
		}
		if (isset($_POST['admin']['new_game']['admin_password2'])) {
			
			$data = $form_handler->SanitizeString($_POST['admin']['new_game']['admin_password2'], PASSWORD_MAX_LENGTH, false, PASSWORD_MIN_LENGTH);
			
			if (!$data) {
				$error = true;
				$form_errors['admin']['new_game']['admin_password2'] = $form_handler->_latest_error;
			}
			else {
				$form_data['new_game']['admin_password2'] = $data;
			}
		}
		if (!$error && isset($form_data['new_game']['admin_password']) && isset($form_data['new_game']['admin_password2'])) {
			
			if ($form_data['new_game']['admin_password'] !== $form_data['new_game']['admin_password2']) {
				$error = true;
				$form_errors['admin']['new_game']['admin_password2'] = localize('ERROR_FORM_HANDLER_PASSWORD_MATCH');
			}
		}
		if (isset($_POST['admin']['new_game']['sample_cards'])) {
			$form_data['new_game']['sample_cards'] = true;
		}
		else {
			$form_data['new_game']['sample_cards'] = false;
		}
		// if form is valid
		if (!$error) {
			
			$user_id = $_SESSION['user']['user_id'];
			global $super_admin_id;
			
			// If user is not super admin give error
			if (doubleval($user_id) !== doubleval($super_admin_id)) {
				$error = true;
				$form_errors['admin']['new_game']['game_name'] = localize('ERROR_NOT_SUPER_ADMIN');
				$_POST['notifications'] = array();
				$_POST['notifications']['new_game_created'] = false;
			}
		}
		
		// If form is valid && user is super admin
		if (!$error) {
			if (isset($form_data['new_game']['admin_username']) && isset($form_data['new_game']['admin_password']) && isset($form_data['new_game']['game_name'])) {
				
				$user = $form_data['new_game']['admin_username'];
				$pass = $form_data['new_game']['admin_password'];
				$game = $form_data['new_game']['game_name'];
				
				$db = DB::getInstance();
				$user_id = $db->createUser($user, $pass);

				if ($user_id > 0) {
					$game_id = $db->createGame($game, $user_id);
					if ($game_id > 0) {
						
						global $languages;
						global $default_language;
						
						// Init extra options of the game
						$extras = array();
						$extras['default_language'] = $default_language;
						$extras['card_template_id'] = 0;
						$db->updateGameExtras($game_id, $extras);
						
						// Add default game texts to database
						foreach ($languages as $lang) {
		
							$lang_file = dirname(__FILE__) . '/../locales/' . $lang . '.txt';
							$lang_file_content = file_get_contents($lang_file, FILE_USE_INCLUDE_PATH);
							// Load the language file as a JSON object and transform it into an associative array
							$translations = json_decode($lang_file_content, true);
			
							$is_default = 0;
			
							if ($lang == $default_language) {
								$is_default = 1;
							}
							$texts = array();
							$texts['welcome'] = $translations['WELCOME_TEXT'];
							$texts['front_up'] = $translations['FRONT_PAGE_TEXT1'];
							$texts['front_down'] = $translations['FRONT_PAGE_TEXT2'];
							$texts['registration_up'] = $translations['REGISTER_PAGE_TEXT1'];
							$texts['registration_down'] = $translations['REGISTER_PAGE_TEXT2'];
							$texts['login_up'] = $translations['LOGIN_PAGE_TEXT1'];
							$texts['login_down'] = $translations['LOGIN_PAGE_TEXT2'];
							$texts['new_up'] = $translations['NEW_SIMULATION_PAGE_TEXT1'];
							$texts['new_down'] = $translations['NEW_SIMULATION_PAGE_TEXT2'];
							$texts['open_up'] = $translations['OPEN_SIMULATION_PAGE_TEXT1'];
							$texts['open_down'] = $translations['OPEN_SIMULATION_PAGE_TEXT1'];
							$texts['continue_up'] = $translations['CONTINUE_SIMULATION_PAGE_TEXT1'];
							$texts['continue_down'] = $translations['CONTINUE_SIMULATION_PAGE_TEXT1'];
							$texts['loading'] = $translations['GETTING_A_LIFE'];
							$texts['your_life'] = $translations['YOUR_LIFE'];
							$texts['menu'] = $translations['MENU'];
							$texts['selection'] = $translations['CHOOSE'];
							
							$db->addOrUpdateGameTexts($game_id, $texts, $lang, $is_default, $default_language);
						}
						
						// Create sample cards if wanted
						if ($form_data['new_game']['sample_cards']) {
							
							$file = dirname(__FILE__) . '/../install/sample_cards.csv';
							$cards = get_cards_from_csv($file);
							
							$creator_id = $user_id;
							$lang = $default_language;
							$latest_card_id = 0;
							
							foreach ($cards as $card) {
								
								if ($card['card_external_id'] == 0) {
									$card['card_external_id'] = $latest_card_id + 1;
									$latest_card_id = $card['card_external_id'];
								}
								else {
									if ($card['card_external_id'] > $latest_card_id) {
										$latest_card_id = $card['card_external_id'];
									}
								}
								$db->importCard($card['card_external_id'], $card['repetitive'], $card['tags'], $card['stat_requirements'], $card['comment'], $card['attachment'], $card['layout'], $card['card_name'], $card['description'], $card['expert_advice'], $card['choices'], $card['results'], $game_id, $lang, $creator_id);
							}
						}
						unset($_POST['admin']['new_game']);
						unset($_POST['admin_index_form_create']);
						unset($form_errors);
						$_POST['notifications'] = array();
						$_POST['notifications']['new_game_created'] = true;
					}
					else {

						if ($game_id == -1) {
							// Remove just created user from db
							$db->deleteUser($user_id);
							$form_errors['admin']['new_game']['game_name'] = localize('ERROR_GAME_EXISTS');
						}
					}
				}
				else {
					if ($user_id == -1) {
						$form_errors['admin']['new_game']['admin_username'] = localize('ERROR_USER_EXISTS');
					}
				}
				if ($error) {
					$_POST['notifications'] = array();
					$_POST['notifications']['new_game_created'] = false;
				}
			}
		}
	}
	
	// Open game form is submitted
	if (isset($_POST['admin_index_form_open'])) {
		
		if (isset($_SESSION['admin']['open_game'])) {
			unset($_SESSION['admin']['open_game']);
		}
		if (isset($_SESSION['admin']['new_game'])) {
			unset($_SESSION['admin']['new_game']);
		}
		$form_data['open_game'] = array();
		$form_errors['admin']['open_game'] = array();
		
		if (isset($_POST['admin']['open_game']['game_name'])) {
			
			$data = $form_handler->ValidateInt($_POST['admin']['open_game']['game_name']);
			if (!$data) {
				$error = true;
				$form_errors['admin']['open_game']['game_name'] = $form_handler->_latest_error;
			}
			else {
				$form_data['open_game']['game_id'] = $data;
			}
		}
		else {
			$form_errors['admin']['open_game']['game_name'] = localize('ERROR_FORM_HANDLER_EMPTY');
		}
		
		// If form is valid
		if (!$error) {

			if (isset($form_data['open_game']['game_id']) && isset($_SESSION['user']['username']) && isset($_SESSION['user']['user_id'])) { //&& isset($form_data['open_game']['username']) && isset($form_data['open_game']['password'])) {
				
				$game_id = $form_data['open_game']['game_id'];
				$username = $_SESSION['user']['username'];
				$user_id = $_SESSION['user']['user_id'];

				$db = DB::getInstance();
				$game = $db->getGame($game_id);
				$admins = $db->getAdminIDs($game_id);
				
				global $super_admin_id;
				
				if (!is_array($game)) {
					$form_errors['admin']['open_game']['game_name'] = localize('ERROR_GAME_NOT_FOUND');
				}
				elseif (!in_array($user_id, $admins) && $user_id != $super_admin_id) {
					$form_errors['admin']['open_game']['game_name'] = localize('ERROR_NOT_ADMIN');
				}
				else {
					unset($_POST['admin']['open_game']);
					$_SESSION['admin']['game'] = $game;
					unset($_POST['admin_index_form_open']);
					unset($form_errors);
					header('Location: editor.php');
					die();
				}
			}
		}	
	}
	
	// Admin login form is submitted
	if (isset($_POST['admin_index_form_login'])) {
		
		$form_data['login'] = array();
		$form_errors['admin']['login'] = array();
		
		if (isset($_POST['admin']['login']['username'])) {
			
			$data = $form_handler->SanitizeString($_POST['admin']['login']['username'], USERNAME_MAX_LENGTH, false);
			
			if (!$data) {
				$error = true;
				$form_errors['admin']['login']['username'] = $form_handler->_latest_error;
			}
			else {
				$form_data['login']['username'] = $data;
			}
		}
		if (isset($_POST['admin']['login']['password'])) {
			
			$data = $form_handler->SanitizeString($_POST['admin']['login']['password'], PASSWORD_MAX_LENGTH, false);
			
			if (!$data) {
				$error = true;
				$form_errors['admin']['login']['password'] = $form_handler->_latest_error;
			}
			else {
				$form_data['login']['password'] = $data;
			}
		}
		// If form is valid
		if (!$error) {
			
			if (isset($form_data['login']['username']) && isset($form_data['login']['password'])) {
				
				$username = $form_data['login']['username'];
				$pass = $form_data['login']['password'];
				
				$db = DB::getInstance();
				
				if (!is_array($user = $db->login($username, $pass))) {
					// Errors:	-1: given user isn't found, -2: wrong password
					if ($user < 0) {
						$form_errors['admin']['login']['username'] = localize('ERROR_LOGIN');
						$form_errors['admin']['login']['password'] = localize('ERROR_LOGIN');
					}
				}
				else {
					unset($_POST['admin']['login']);
					unset($_POST['admin_index_form_login']);
					unset($form_errors);
				}
			}
		}
	}
	// Change password form is submitted
	if (isset($_POST['change_password'])) {
		
		if (isset($_POST['notifications'])) {
			unset($_POST['notifications']);
		}
		$form_data['editor'] = array();
		$form_errors['editor']['settings'] = array();
		
		// Check that both password fields are not empty and if not process those
		if (isset($_POST['editor']['settings']['new_password']) && isset($_POST['editor']['settings']['new_password2']) && (!empty($_POST['editor']['settings']['new_password']) || !empty($_POST['editor']['settings']['new_password2']))) {
//		if (isset($_POST['editor']['settings']['new_password'])) {
			
			$data = $form_handler->SanitizeString($_POST['editor']['settings']['new_password'], PASSWORD_MAX_LENGTH, false, PASSWORD_MIN_LENGTH);
			
			if (!$data) {
				$error = true;
				$form_errors['editor']['settings']['new_password'] = $form_handler->_latest_error;
			}
			else {
				$form_data['settings']['new_password'] = $data;
			}
//		}
//		if (isset($_POST['editor']['settings']['new_password2'])) {
			
			$data = $form_handler->SanitizeString($_POST['editor']['settings']['new_password2'], PASSWORD_MAX_LENGTH, false, PASSWORD_MIN_LENGTH);
			
			if (!$data) {
				$error = true;
				$form_errors['editor']['settings']['new_password2'] = $form_handler->_latest_error;
			}
			else {
				$form_data['settings']['new_password2'] = $data;
			}
		}
		if (!$error && isset($form_data['settings']['new_password']) && isset($form_data['settings']['new_password2'])) {
			
			if ($form_data['settings']['new_password'] !== $form_data['settings']['new_password2']) {
				$error = true;
				$form_errors['editor']['settings']['new_password2'] = localize('ERROR_FORM_HANDLER_PASSWORD_MATCH');
			}
		}
		
		if (isset($_POST['editor']['settings']['email'])) {
			
			$email = trim($_POST['editor']['settings']['email']);
			if (!empty($email)) {
				$data = $form_handler->ValidateEmail($email);
			
				if (!$data) {
					$error = true;
					$form_errors['editor']['settings']['email'] = $form_handler->_latest_error;
				}
				else {
					$form_data['settings']['email'] = $data;
				}
			}
			else {
				$form_data['settings']['email'] = '';
			}
		}
		
		if (!$error && isset($_POST['editor']['settings']['current_password'])) {
			
			$data = $form_handler->SanitizeString($_POST['editor']['settings']['current_password'], PASSWORD_MAX_LENGTH, false, PASSWORD_MIN_LENGTH);
			
			if (!$data) {
				$error = true;
				$form_errors['editor']['settings']['current_password'] = $form_handler->_latest_error;
			}
			else {
				$form_data['settings']['current_password'] = $data;
				
				if (isset($_SESSION['user']['username'])) {
					$db = DB::getInstance();
					if (isset($form_data['settings']['new_password']) && isset($form_data['settings']['new_password2'])) {
						// Try to change the password
						if (!$db->changePassword($_SESSION['user']['username'], $form_data['settings']['current_password'], $form_data['settings']['new_password'])) {
							$error = true;
							$form_errors['editor']['settings']['current_password'] = localize('ERROR_ADMIN_EDITOR_PASSWORD');
						}
					}
					if (!$error && isset($form_data['settings']['email'])) {
						$password = $form_data['settings']['current_password'];
						if (isset($form_data['settings']['new_password'])) {
							$password = $form_data['settings']['new_password'];
						}
						// Try to change the email address
						if (!$db->changeEmail($_SESSION['user']['username'], $password, $form_data['settings']['email'])) {
							$error = true;
							$form_errors['editor']['settings']['current_password'] = localize('ERROR_ADMIN_EDITOR_PASSWORD');
						}
						else {
							$_SESSION['user']['email'] = $form_data['settings']['email'];
						}
					}
				}
				else {
					$error = true;
				}
			}
		}
		// If form is valid
		if (!$error) {
			unset($_POST['editor']['settings']['new_password']);
			unset($_POST['editor']['settings']['new_password2']);
			unset($_POST['editor']['settings']['email']);
			unset($_POST['editor']['settings']['current_password']);
			unset($_POST['change_password']);
			$_POST['notifications'] = array();
			$_POST['notifications']['password_changed'] = true;
		}
		else {
			$_POST['notifications'] = array();
			$_POST['notifications']['password_changed'] = false;
		}
	}
}