<?php
/**
*	@file simulation.php
*	@brief Simulation main page.
*	Handles simulation initialization based on session variables
*	and runs it with JavaScript and AJAX.
*/
require_once(dirname(__FILE__) . '/app_functions.php');
do_basic_operations();
/** Database instance of either #MySQLDB or #XMLDB */
$db = DB::getInstance();
/** Configuration instance of Config */
$config = Config::getInstance();
/** Get current simulation value from get parameter if not exist show 404 page */
$current_simulation = 0;

$slug = '';
if (isset($_GET['game_slug'])) {
			
	$slug = friendly_url($_GET['game_slug']);

	if (isset($_SESSION['game']['slug']) && $_SESSION['game']['slug'] == $slug) {
		$current_simulation = $_SESSION['game']['game_id'];
	}
	else {
		// Get corresponding game_id based on given slug
		$game_id = $db->getGameIdBySlug($slug);
		if ($game_id > 0) {
			$current_simulation = $game_id;
		}
	}
}
if ($current_simulation < 1) {
	header("HTTP/1.0 404 Not Found");
	exit("Not Found");
}

// if user edited settings process forms
if (isset($_POST['change_password']) || isset($_POST['user_open_game']) || isset($_POST['delete_profile_modal_yes_button'])) {
	process_app_forms();
}
if (isset($_SESSION['user']['username']) && isset($_SESSION['game']['game_id']) && isset($_SESSION['game']['name']) && isset($_SESSION['game']['profile'])) {
  	$username = $_SESSION['user']['username'];
  	$game_id = $_SESSION['game']['game_id'];
  	$game_name = $_SESSION['game']['name'];
  	$profile_id = $_SESSION['game']['profile'];
}
else {
	header('Location: ' . formatAppLink($config->baseurl . 'app/index.php?game_slug=' . $slug));
	die();
}

/** Global default language. */
global $language;
/** GameEngine object containing simulation specific information based on $game_id and $profile_id. */
$game = new GameEngine($game_id, $profile_id, $language);

// If has ended redirect to ending page
if ($game->game_ended) {
	header('Location: ' . formatAppLink($config->baseurl . 'app/end.php?game_slug=' . $slug));
	die();
}

// Get game texts from db and define which translation to use
/** 
 * Contains information of texts of the current game retrieved by MySQLDB::getAllGames
 * or XMLDB::getGameTexts.
 */
$game_texts = $db->getGameTexts($game_id);
/** Game texts in default language. */
$default_lang_texts = array();
/** Game texts in currently active language. */
$current_lang_texts = array();

// Loop through texts array and find correct translations
foreach ($game_texts as $trans) {
	if ($trans['language_code'] == $language) {
		$current_lang_texts = $trans;
	}
	if ($trans['is_default'] == 1) {
		$default_lang_texts = $trans;
	}
	// If both are found then break
	if (!empty($current_lang_texts) && !empty($default_lang_texts)) {
		break;
	}
}

/** If translation for current language is found contains texts of that. Otherwise texts are in default language. */
$texts = array();

// If translation for current language is found use that. Otherwise use default one
if (!empty($current_lang_texts)) {
	$texts = $current_lang_texts;
}
else {
	$texts = $default_lang_texts;
}

print_app_html_start('APP_INDEX_TITLE');
print_app_header($game->player_stats);
/** Contains simulation page errors */
$app_form_errors = array();
/** An array to hold errors in form if any. Defined in app_form_handling.php */
global $form_errors;

if (!empty($form_errors)) {
	$app_form_errors = $form_errors;
}
if ($current_simulation > 0) :
	$this_game = $db->getGame($current_simulation);
?>
<style>
<!--
<?php // Custom background color
	if (isset($this_game['background_color']) && !empty($this_game['background_color'])) :
?>
html, input[type="text"], input[type="password"] {
	background-color: <?php echo('#' . $this_game['background_color']); ?>;
	background-image: none;
}
.simulation_select_button, .simulation_select, .hidden_header_show_hide, .hidden_header {
	color: <?php echo('#' . $this_game['background_color']); ?>;
}
.simulation_selected_button:hover, .selected_language  {
	color: <?php echo('#' . $this_game['background_color']); ?> !important;
}
/* Pop ups: */
.jqmWindow, .jqmDialog, .jqmUserSettings, .jqmDialog2 {
	background-color: <?php echo('#' . $this_game['background_color']); ?>;
}
<?php 
	endif;
	// Custom background tile
	if (isset($this_game['background_tile']) && !empty($this_game['background_tile'])) :
		global $image_folder;
		$current_image_folder = $image_folder;
		if (isset($this_game['image_folder']) && !empty($this_game['image_folder'])) {
			$current_image_folder = $this_game['image_folder'];
		}
		$config = Config::getInstance();
		$background_tile_url = $config->baseurl . $current_image_folder . $this_game['background_tile'];
?>
html {
	background-image: url(<?php echo($background_tile_url); ?>);
}
<?php 
	endif;
	// Custom text color
	if (isset($this_game['text_color']) && !empty($this_game['text_color'])) :
?>
html, h1, h2, h3, h4, h5, p, label, hr, .simulation_select_button:hover {
	color: <?php echo('#' . $this_game['text_color']); ?>;
}
.hidden_header_background_repeat {
	 /*box-shadow: 0 1px 5px <?php echo('#' . $this_game['text_color']); ?>;*/
	 background-color: <?php echo('#' . $this_game['text_color']); ?>;
}
.hidden_header {
	 background-color: <?php echo('#' . $this_game['text_color']); ?>;
}
input[type="text"], input[type="password"] {
    border: 1px solid <?php echo('#' . $this_game['text_color']); ?>;
    color: <?php echo('#' . $this_game['text_color']); ?>;
}
<?php 
	endif;
	// Custom link color
	if (isset($this_game['link_color']) && !empty($this_game['link_color'])) :
?>
a, .hidden_header_show_hide:hover, #hidden_header_columns a, #hidden_header_columns dd {
	color: <?php echo('#' . $this_game['link_color']); ?>;
}
.simulation_select_button, .simulation_select {
	background-color: <?php echo('#' . $this_game['link_color']); ?>;
}
.simulation_selected_button:hover {
	background-color: <?php echo('#' . $this_game['link_color']); ?> !important;
}
<?php 
	endif;
	// Custom link hover color
	if (isset($this_game['link_hover_color']) && !empty($this_game['link_hover_color'])) :
?>
a:hover, #hidden_header_columns a:hover {
	color: <?php echo('#' . $this_game['link_hover_color']); ?>;
}
.simulation_select_button:hover {
	background-color: <?php echo('#' . $this_game['link_hover_color']); ?>;
}
<?php 
	endif;
	// Custom button color
	if (isset($this_game['button_color']) && !empty($this_game['button_color'])) :
?>
button, input[type=submit], #delete_profile_button {
	color: <?php echo('#' . $this_game['button_color']); ?>;
}
<?php 
	endif;
	// Custom button hover color
	if (isset($this_game['button_hover_color']) && !empty($this_game['button_hover_color'])) :
?>
button:hover, input[type=submit]:hover, #delete_profile_button:hover {
	color: <?php echo('#' . $this_game['button_hover_color']); ?>;
}
<?php 
	endif;
?>
-->
</style>
<?php
	// Custom logo
	if (isset($this_game['logo']) && !empty($this_game['logo'])) :
		global $image_folder;
		$current_image_folder = $image_folder;
		if (isset($this_game['image_folder']) && !empty($this_game['image_folder'])) {
			$current_image_folder = $this_game['image_folder'];
		}
		$config = Config::getInstance();
		$logo_url = $config->baseurl . $current_image_folder . $this_game['logo'];
?>
<style>	
<!--
.hidden_header_logo, .hidden_header_logo:hover {
	background-image: url("<?php echo($logo_url); ?>");
	background-size: contain;
}
-->
</style>
<?php	
	endif;
endif;

/** Contains information about current card in play from GameEngine::getCurrentCard. */
$current_card = $game->getCurrentCard();
/** Contains information about previous card played from GameEngine::getPrevCard. */
$previous_card = $game->getPrevCard();
		
// If there's no previous card fill previous card with current card values
// so that first back would lead to first card.
if (empty($previous_card)) {
	$previous_card = $current_card;
}
		
/** Contains number of played cards retrieved with GameEngine::countPlayedCards. */
$played_cards_count = $game->countPlayedCards();
/** Global default image folder location. */
global $image_folder;
		
if (empty($_SESSION['game']['image_folder'])) {
	$_SESSION['game']['image_folder'] = str_replace('\\', '/', $image_folder);
}

/** GameEngine object is stored to session variable. */
$_SESSION['game_object'] = $game; 

$show_user_settings = false;
if (!empty($app_form_errors['user']['settings'])) {
	$show_user_settings = true;
}
if (isset($_POST['notifications']['password_changed'])) {
	$show_user_settings = true;
}
?>
	<div class="clear"></div>
	<div id="panel_wrapper" class="panel_wrapper">
	
		<div id="panel_mask_app" class="panel_mask">
			<div id="simulation_prev_card_panel" class="panel_item panel_item_app">
				<div class="panel_content" >
					<input type="hidden" id="prev_card_id" value="<?php if($played_cards_count > 1 && isset($previous_card['card_id'])): echo($previous_card['card_id']); else: echo('0'); endif; ?>" />
					<div id="simulation_card_image">	
						<img src="<?php if(isset($previous_card['attachment'])): if (!empty($previous_card['attachment'])): echo($config->baseurl . $_SESSION['game']['image_folder'] . $previous_card['attachment']); endif; endif; ?>" alt="<?php echo localize("IMAGE_ALT_CARD"); ?>" />
					</div>
					<h2 id="simulation_card_name"><?php if(isset($previous_card)): if (!empty($previous_card['card_name'])): echo($previous_card['card_name']); elseif (!empty($previous_card['default_name'])): echo($previous_card['default_name']); endif; else: echo('N/A'); endif; ?></h2>
					<div id="simulation_card_description">
					<?php if (isset($previous_card['description']) && !empty($previous_card['description'])) :
								echo($previous_card['description']);
							elseif (isset($previous_card['default_description']) && !empty($previous_card['default_description'])) :
								echo($previous_card['default_description']); 
							else: echo('N/A');
							endif;
					?>
					</div>	
					<h2 class="selection_text" <?php if (!isset($previous_card['choices']) || empty($previous_card['choices'])) echo( 'style="display:none;"'); ?>><?php echo $texts['selection']; ?></h2>
					<div id="simulation_card_prev_choices">
						<?php if (isset($previous_card['choices'])) :?>
						<?php 	foreach ($previous_card['choices'] as $choice) : ?>
						<button class="simulation_select_button select_prev" name="simulation_prev_choices" id="simulation_prev_choices_<?php echo $choice['choice_id']; ?>" value="<?php echo $choice['choice_id']; ?>"><?php if (isset($choice['choice_text']) && !empty($choice['choice_text'])) : echo $choice['choice_text']; elseif (isset($choice['default_text']) && !empty($choice['default_text'])) : echo $choice['default_text']; endif; ?></button>
						<?php 	endforeach; ?>
						<?php endif; ?>
					</div>
					<h3><a href="#" id="continue_simulation_prev_button" <?php if (isset($previous_card['choices']) && !empty($previous_card['choices'])) echo( 'style="display:none;"'); ?>><?php echo localize('CONTINUE')?></a></h3>	
					<div id="simulation_prev_result_loading" class="result_loading"><img src="<?php echo($config->baseurl); ?>img/loading.gif" alt="<?php echo localize('IMAGE_ALT_LOADING'); ?>" /></div>
					<div id="simulation_prev_result_content">
						<div id="simulation_result_description"></div>
						<h3><a href="#simulation_loading_panel" id="simulation_continue_prev" class="panel_link"><?php echo localize('CONTINUE')?></a></h3>
					</div>	
					<?php if ($_SESSION['game']['use_expert_advice']) : ?>
					<div id="simulation_card_prev_expert_advice" <?php if (empty($previous_card['expert_advice']) && empty($previous_card['default_expert_advice'])) : echo(' style="display:none;"'); endif; ?>>
						<h3><a class="expert_advice_link" href="#"><?php echo localize('APP_SIMULATION_EXPERT_ADVICE'); ?></a></h3>
						<?php $prev_expert_advice = '';
								if (!empty($previous_card['expert_advice'])) {
									$prev_expert_advice = $previous_card['expert_advice'];
								} elseif (!empty($previous_card['default_expert_advice'])) {
									$prev_expert_advice = $previous_card['default_expert_advice']; 
								}
						?>
						<div class="expert_advice"><?php echo $prev_expert_advice; ?></div>
					</div>
					<?php endif; ?>	
					<?php // count of played_cards represents the cards get not the choices made ?>
					<h3><a <?php if ($played_cards_count < 3) : ?>style="display:none;"<?php endif; ?> class="panel_link simulation_prev_prev" href="#simulation_loading_panel"><?php echo localize('BACK'); ?></a></h3>
				</div>
			</div>
			
			<div id="simulation_current_card_panel" class="panel_item panel_item_app">
				<div class="panel_content" >
					<input type="hidden" id="current_card_id" value="<?php if($played_cards_count > 0 && isset($current_card['card_id'])) : echo($current_card['card_id']); else: echo('0'); endif; ?>" />
					<div id="simulation_card_image">
						<img src="<?php if(isset($current_card['attachment'])): if (!empty($current_card['attachment'])): echo($config->baseurl . $_SESSION['game']['image_folder'] . $current_card['attachment']); endif; endif; ?>" alt="<?php echo localize("IMAGE_ALT_CARD"); ?>" />
					</div>
					<h2 id="simulation_card_name"><?php if(isset($current_card)): if (!empty($current_card['card_name'])): echo($current_card['card_name']); elseif (!empty($current_card['default_name'])): echo($current_card['default_name']); endif; else: echo('N/A'); endif; ?></h2>
					<?php 
						$description = 'N/A';
						if (isset($current_card['description']) && !empty($current_card['description'])) {
							$description = $current_card['description'];
						}
						elseif (isset($current_card['default_description']) && !empty($current_card['default_description'])) {
							$description = $current_card['default_description']; 
						}
/*						$stat_names = array_keys($game->player_stats);
						$stat_values = array_values($game->player_stats);
	
						for ($i = 0; $i < count($stat_names); $i++) {
							$description = str_replace(PLAYER_STAT_TAG_START . $stat_names[$i] . PLAYER_STAT_TAG_END, str_replace('=', '', $stat_values[$i]), $description);
						}	
*/					
						$description = generate_dynamic_text($description, $game->player_stats);
					?>
					<div id="simulation_card_description"><?php echo $description; ?></div>
					<h2 class="selection_text" <?php if (!isset($current_card['choices']) || empty($current_card['choices'])) echo( 'style="display:none;"'); ?>><?php echo $texts['selection']; ?></h2>
					<div id="simulation_card_current_choices">
						<?php if (isset($current_card['choices'])) :?>
						<?php 	foreach ($current_card['choices'] as $choice) : ?>
						<?php 		$choice_text = '';
										if (isset($choice['choice_text']) && !empty($choice['choice_text'])) {
											$choice_text = $choice['choice_text'];
										}
										elseif (isset($choice['default_text']) && !empty($choice['default_text'])) {
											$choice_text = $choice['default_text'];
										}
/*										for ($i = 0; $i < count($stat_names); $i++) {
											$choice_text = str_replace(PLAYER_STAT_TAG_START . $stat_names[$i] . PLAYER_STAT_TAG_END, str_replace('=', '', $stat_values[$i]), $choice_text);
										}	
*/						
										$choice_text = generate_dynamic_text($choice_text, $game->player_stats);
						?>
						<button class="simulation_select_button select_current" name="simulation_current_choices" id="simulation_current_choices_<?php echo $choice['choice_id']; ?>" value="<?php echo $choice['choice_id']; ?>"><?php echo $choice_text; ?></button>
						<?php 	endforeach; ?>
						<?php endif; ?>
					</div>
					<h3><a href="#" id="continue_simulation_current_button" <?php if (isset($current_card['choices']) && !empty($current_card['choices'])) echo( 'style="display:none;"'); ?>><?php echo localize('CONTINUE')?></a></h3>	
					<div id="simulation_current_result_loading" class="result_loading"><img src="<?php echo($config->baseurl); ?>img/loading.gif" alt="<?php echo localize('IMAGE_ALT_LOADING'); ?>" /></div>
					<div id="simulation_current_result_content">
						<div id="simulation_result_description"></div>
						<h3><a href="#simulation_loading_panel" id="simulation_continue_current" class="panel_link"><?php echo localize('CONTINUE')?></a></h3>
					</div>
					<?php if ($_SESSION['game']['use_expert_advice']) : ?>
					<div id="simulation_card_current_expert_advice"<?php if (empty($current_card['expert_advice']) && empty($current_card['default_expert_advice'])) : echo(' style="display:none;"'); endif; ?>>
						<h3><a class="expert_advice_link" href="#"><?php echo localize('APP_SIMULATION_EXPERT_ADVICE'); ?></a></h3>
						<div class="expert_advice">
						<?php if (!empty($current_card['expert_advice'])) :
									echo($current_card['expert_advice']);
								elseif (!empty($current_card['default_expert_advice'])) :
									echo($current_card['default_expert_advice']); 
								endif;
						?>
						</div>
					</div>
					<?php endif; ?>
					<?php // count of played_cards represents the cards get not the choices made ?>
					<h3><a <?php if ($played_cards_count < 2) : ?>style="display:none;"<?php endif; ?> class="panel_link simulation_prev" href="#simulation_loading_panel"><?php echo localize('BACK'); ?></a></h3>
				</div>
			</div>
			
			<div id="simulation_loading_panel" class="panel_item panel_item_app">
				<div class="panel_content">
					<div id="simulation_next_card_loading">
					
						<h2><?php echo $texts['loading']; ?></h2>
						<a href="#simulation_current_card_panel" id="simulation_next" class="panel_link"><?php echo localize('CONTINUE')?></a>
					</div>
					<span>&nbsp;</span>
				</div>
			</div>
			
		</div> <!-- #panel_mask_app -->
	</div> <!-- #panel_wrapper -->
	
	<div class="clear"></div>
	<div id="debug">
		<input type="hidden" id="simulation_debug_player_profile" value="<?php echo $profile_id; ?>" />
	</div>
	
	<div class="jqmUserSettings" id="user_settings_modal">
		<a href="#" class="jqmClose" id="user_settings_modal_close"><?php echo localize('CLOSE'); ?></a>
		<h2><?php echo localize('ADMIN_EDITOR_USER_SETTINGS')?></h2>
		<br />
<?php if ($_POST['notifications']['password_changed']) : ?>
		<p class="notification">
			<?php echo localize('ADMIN_EDITOR_NOTIFICATION_PASSWORD_CHANGED'); ?>
		</p>
<?php endif; ?>
		<form id="user_settings_form" class="app_form" method="post" action="">
			<div class="left" id="user_settings_left">
				<label for="user[settings][new_password]"><?php echo localize('ADMIN_EDITOR_CHANGE_PASSWORD')?></label><input class="" type="password" name="user[settings][new_password]" id="user[settings][new_password]" value="<?php if(isset($_POST['user']['settings']['new_password'])) echo $_POST['user']['settings']['new_password']; ?>" />
				<?php	if (isset($app_form_errors['user']['settings']['new_password'])) : ?>
				<p class="error"><?php echo $app_form_errors['user']['settings']['new_password']; ?></p>
				<?php endif; ?>
				<label for="user[settings][new_password2]"><?php echo localize('ADMIN_EDITOR_CHANGE_PASSWORD2')?></label><input class="" type="password" name="user[settings][new_password2]" id="user[settings][new_password2]" value="<?php if(isset($_POST['user']['settings']['new_password2'])) echo $_POST['user']['settings']['new_password2']; ?>" />
				<?php	if (isset($app_form_errors['user']['settings']['new_password2'])) : ?>
				<p class="error"><?php echo $app_form_errors['user']['settings']['new_password2']; ?></p>
				<?php endif; ?>
				<label for="user[settings][current_password]"><?php echo localize('ADMIN_EDITOR_CURRENT_PASSWORD')?></label><input class="" type="password" name="user[settings][current_password]" id="user[settings][current_password]" value="<?php if(isset($_POST['user']['settings']['current_password'])) echo $_POST['user']['settings']['current_password']; ?>" />
				<?php	if (isset($app_form_errors['user']['settings']['current_password'])) : ?>
				<p class="error"><?php echo $app_form_errors['user']['settings']['current_password']; ?></p>
				<?php endif; ?>
				<br />
				<input class="" type="submit" class="" id="change_password" name="change_password" value="<?php echo localize('SAVE')?>" />
			</div>
			<div class="right" id="user_settings_right">
				<button class="right" id="delete_profile_button" name="delete_profile_button"><?php echo localize('ADMIN_EDITOR_DELETE_PROFILE')?></button>
			</div>
			<div class="clear"></div>
			<br />
			<?php $user_games = array(); ?>
			<?php if (isset($_SESSION['user']['user_id'])): $user_games = $db->getUsersGames($_SESSION['user']['user_id']); endif; ?>
			<?php print_app_saved_games($user_games, $current_simulation); ?>
			<br />
		</form>
	</div>
	
	<?php print_app_delete_saved_game_modal(); ?>
	
	<a id="show_link_profile_modal" href="#"></a>
	<div class="jqmDialog2" id="link_profile_modal">
		<a href="#" class="jqmClose" id="link_profile_modal_close1"><?php echo localize('APP_SIMULATION_STAY_ON_PAGE')?></a>
		<div class="jqmdBL"><div class="jqmdBR"><div class="jqmdBC">
			<div class="jqmdMSG">
				<br />
				<br />
				<br />
				<div class="centered largeText">
					<?php echo localize('APP_SIMULATION_CREATE_USER_AND_LINK_PROFILE')?>
				</div>
				<br />
				<div class="centered buttons">
					<input type="submit" class="jqmClose" id="link_profile_modal_register" value="<?php echo localize("YES"); ?>" />
					<input type="submit" class="jqmClose" id="link_profile_modal_close2" value="<?php echo localize("NO"); ?>" />
				</div>
			</div>
			</div></div>
		</div>
	</div>
	
	<div id="delete_profile_modal" class="jqmDialog jqmdWide">
		<a href="#" class="jqmClose" id="delete_profile_modal_close"><?php echo localize('CLOSE'); ?></a>
		<div class="jqmdBL"><div class="jqmdBR"><div class="jqmdBC">
		
		<div class="jqmdMSG">
			<br />
			<br />
			<div class="centered largeText">
				<?php echo localize('APP_SIMULATION_CONFIRM_DELETE_PROFILE')?>
			</div>
			<p><?php echo localize('APP_SIMULATION_CONFIRM_DELETE_PROFILE_DESCRIPTION')?></p>
			<br />
			<form method="post" action="#">
				<div class="centered buttons">
					<input type="submit" class="" id="delete_profile_modal_yes_button" name="delete_profile_modal_yes_button" value="<?php echo localize("YES"); ?>" />
					<input type="submit" class="jqmClose" id="delete_profile_modal_no_button" name="delete_profile_modal_no_button" value="<?php echo localize("NO"); ?>" />
				</div>
			</form>
		</div>

		</div></div></div>

	</div>
		
<script type="text/javascript">
<!--
/*
var simulation_modules = [];

if (typeof window.Globe == 'function') {
	simulation_modules.push(new Globe());
}

var simulation = new Simulation(<?php echo $profile_id; ?>, simulation_modules);

window.showAddAccountPopupOnLeave = true;
window.internalLinkClicked = false; // Thats for internal links so that browser won't ask if you want to leave
$(document).ready(function() {

	simulation.init();
*/
window.showAddAccountPopupOnLeave = true;
window.internalLinkClicked = false; // Thats for internal links so that browser won't ask if you want to leave
$(document).ready(function() {
	
	function confirmBeforeUnload(e) {

		if (window.showAddAccountPopupOnLeave && !window.internalLinkClicked) {

			var e = e || window.event;
			$('#show_link_profile_modal').click();
			// For IE and Firefox
			if (e) {
				e.returnValue = '<?php echo(localize("APP_SIMULATION_LEAVING_CONFIRMATION")); ?>';
			}

			// For Safari
			return '<?php echo(localize("APP_SIMULATION_LEAVING_CONFIRMATION")); ?>';
		}
	}
	
// Show user settings popup when needed
<?php if ($show_user_settings) : ?>
	$('#user_settings_button').click();
<?php endif; ?>

<?php if ($_SESSION['isLogged']) : ?>
	window.showAddAccountPopupOnLeave = false;
<?php elseif (isset($_SESSION['game']['use_login']) && !$_SESSION['game']['use_login']) : ?>
	window.showAddAccountPopupOnLeave = false;
<?php else: ?>
	$('.log_out').click( function (e) {
		e.preventDefault();
		window.showAddAccountPopupOnLeave = false;
		$('#show_link_profile_modal').click();
	});
	// Make sure that dialog isn't shown when link is clicked
	$("a, button, input").on("click", function(e) {
		window.internalLinkClicked = true;
		// Set timer to disable this again after 1 second
		window.setInterval(function(){
				window.internalLinkClicked = false;
			},1000);
	});
<?php endif; ?>
	//Popup if unregistered user tries to leave page
	if (window.showAddAccountPopupOnLeave) { 
		window.onbeforeunload = confirmBeforeUnload;
	}
});
//-->
</script>
<?php 
print_html_end();
?>