<?php
/**
*	@file ajax.php
*	@brief Contains AJAX functions of GAL2.
*/
require_once(dirname(__FILE__) . '/functions.php');
session_start();
date_default_timezone_set("Europe/Helsinki");
mb_internal_encoding("UTF-8");

/** Default language of GAL2 */
global $language;


if (isset($_REQUEST['lang']) && !empty($_REQUEST['lang'])) {
	$_SESSION["lang"] = $_REQUEST['lang'];
}
if (isset($_SESSION["lang"]) && !empty($_SESSION["lang"])) {
	$language = $_SESSION["lang"];
}
// Check if session has been expired
if (!isset($_SESSION['active'])) {
	$_SESSION['active'] = false;
}


/** Defines which AJAX action is requested */
$action = '';


if (isset($_REQUEST['action'])) {
	$action = $_REQUEST['action'];
}

switch ($action) {
	case 'get_card':
		card_to_json();
		break;
	case 'get_multiple_cards':
		multiple_cards_to_json();
		break;
	case 'print_multiple_cards':
		multiple_cards_to_html();
		break;
	case 'print_card_choices_and_results':
		card_choices_and_results_to_html();
		break;
	case 'add_choice':
		print_new_choice();
		break;
	case 'add_result':
		print_new_result();
		break;
	case 'add_condition':
		print_new_condition();
		break;
	case 'add_option':
		print_new_option();
		break;
	case 'get_card_translations':
		card_translations_to_json();
		break;
	case 'print_card_translations':
		card_translations_to_html();
		break;
	case 'add_card_translation':
		add_new_translation();
		break;
	case 'get_all_tags_and_stats':
		tags_and_stats_to_json();
		break;
	case 'get_all_tags':
		tags_to_json();
		break;
	case 'get_all_stats':
		stats_to_json();
		break;
	case 'print_played_cards':
		played_cards_to_html();
		break;
	case 'print_player_stats':
		player_stats_to_html();
		break;
	case 'get_player_stats':
		player_stats_to_json();
		break;
	case 'save_choice_and_give_result':
		save_choice_and_return_result_json();
		break;
	case 'play_card':
		play_card_return_card_to_json();
		break;
	case 'previous_card':
		rewind_and_return_cards_to_json();
		break;
	case 'print_card_choices':
		card_choices_to_html();
		break;
	case 'enable_disable_card':
		enable_disable_card();
		break;
	case 'delete_card':
		delete_card();
		break;
	case 'delete_profile':
		delete_profile();
		break;
	case 'change_card_display_lang':
		change_card_display_lang();
		break;
	case 'get_result':
		result_to_json();
		break;
	case 'get_profiles':
		player_profiles_to_json();
		break;
	case 'export_profiles':
		generate_profiles_file();
		break;
	case 'export_cards':
		generate_cards_file();
	case 'replace_stat_tags':
		replace_stat_tags();
		break;
	case 'get_cards_with_limit':
		multiple_cards_with_limit_to_json();
		break;
	case 'updateSession':
		updateSession();
		break;
	case 'admin_create_new_user':
		createNewAdmin();
		break;
	case 'create_globe_image':
		createGlobeImage();
	default:
		break;
}


/**
* Function to inform that session has expired.
* @return JSON response 'session_expired'=true
*/
function session_expired() {
	
	$response['session_expired'] = true;
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($response);
	exit;
}

/**
* Function to get tags and stats related to current game as JSON.
* Used in admin view and needs $_SESSION['admin']['game'].
* @return JSON response containing an array of tags which each starts with #
* and an array of stats starting with @
*/
function tags_and_stats_to_json() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	
	$game;
	if (isset($_SESSION['admin']['game'])) {
		$game = $_SESSION['admin']['game'];
	}
	elseif (isset($_SESSION['game'])) {
		$game = $_SESSION['game'];
	}
	$tags_and_stats = $db->getAllTagsAndStats($game['game_id']);
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($tags_and_stats);
	exit;
}

/**
* Function to get tags related to current game as JSON.
* Used in admin view and needs $_SESSION['admin']['game'].
* @return JSON response containing an array of tags which each starts with #
*/
function tags_to_json() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	
	$game;
	if (isset($_SESSION['admin']['game'])) {
		$game = $_SESSION['admin']['game'];
	}
	
	$tags = $db->getAllTags($game['game_id']);
	
	/*foreach ($tags as &$tag) {
		$tag = '#' . $tag;
	}*/
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($tags);
	exit;
}

/**
* Function to get stats related to current game as JSON.
* Used in admin view and needs $_SESSION['admin']['game'].
* @return JSON response containing an array of stats which each starts with @
*/
function stats_to_json() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	
	$game;
	if (isset($_SESSION['admin']['game'])) {
		$game = $_SESSION['admin']['game'];
	}
	elseif (isset($_SESSION['game'])) {
		$game = $_SESSION['game'];
	}
	$stats = $db->getAllStats($game['game_id']);
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($stats);
	exit;
}

/**
* Function to get current card just played from GameEngine class as JSON.
* Needs $_GET['profile_id'] and $_SESSION['game_object'].
* @return JSON response containing an array of card's properties
* and boolean information if 'game_ended' and if 'back_enabled'
*/
function play_card_return_card_to_json() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	$game;
	if (isset($_SESSION['game_object'])) {
		$game = $_SESSION['game_object'];
	}
	$current_card = array();
	$current_card = $game->getCurrentCard();
	
	$profile_id = 0;
	if (isset($_GET['profile_id'])) {
		$profile_id = doubleval($_GET['profile_id']);
	}
	$stats = get_profile_stats($profile_id);
	
	$text = '';
	if ($current_card['description']) {
		$text = $current_card['description'];
	}
	else {
		$text = $current_card['default_description'];
	}
	// Replace stat based tags
	$modified_text = generate_dynamic_text($text, $stats);
	// Replace player name tag
	$modified_text = replace_player_name($modified_text, $profile_id);
	
	if ($current_card['description']) {
		$current_card['description'] = $modified_text;
	}
	else {
		$current_card['description_default'] = $modified_text;
	}
	
	$current_card['back_enabled'] = $game->allowCancellation();
	
	global $image_folder;
		
	if (isset($_SESSION['game']['image_folder']) && empty($_SESSION['game']['image_folder'])) {
		$_SESSION['game']['image_folder'] = str_replace('\\', '/', $image_folder);
	}
	$config = Config::getInstance();
	if (isset($current_card['attachment']) && !empty($current_card['attachment'])) {
		
		$current_card['imageURL'] = $config->baseurl . $_SESSION['game']['image_folder'] . $current_card['attachment'];
	}
	// If game ended inform that
	if ($game->game_ended) {
		$current_card['game_ended'] = true;
	}
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($current_card);
	exit;
}

/**
* Function to rewind current game to it's previous state.
* Needs $_POST['profile_id'] and $_SESSION['game_object'].
* @return JSON response containing an array of previous card as 'current'
* and card before that as 'previous' if exists.
* Tells also if 'back_enabled' or 'game_ended'
*/
function rewind_and_return_cards_to_json() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	$game;
	if (isset($_SESSION['game_object'])) {
		$game = $_SESSION['game_object'];
	}
	$game->rewind();
	
	$cards = array();
	$cards['current'] = $game->getCurrentCard();
	$previous = $game->getPrevCard();
	if (!empty($previous)) {
		$cards['previous'] = $previous;
	}
	
	$profile_id = 0;
	if (isset($_POST['profile_id'])) {
		$profile_id = doubleval($_POST['profile_id']);
	}
	$stats = get_profile_stats($profile_id);
	
	$text = '';
	if ($cards['current']['description']) {
		$text = $cards['current']['description'];
	}
	else {
		$text = $cards['current']['default_description'];
	}
	// Replace stat based tags
	$modified_text = generate_dynamic_text($text, $stats);
	// Replace player name tag
	$modified_text = replace_player_name($modified_text, $profile_id);
	
	if ($cards['current']['description']) {
		$cards['current']['description'] = $modified_text;
	}
	else {
		$cards['current']['description_default'] = $modified_text;
	}
	
	$cards['back_enabled'] = $game->allowCancellation();
	
	global $image_folder;
		
	if (isset($_SESSION['game']['image_folder']) && empty($_SESSION['game']['image_folder'])) {
		$_SESSION['game']['image_folder'] = str_replace('\\', '/', $image_folder);
	}
	$config = Config::getInstance();
	if (isset($cards['current']['attachment']) && !empty($cards['current']['attachment'])) {
		
		$cards['current']['imageURL'] = $config->baseurl . $_SESSION['game']['image_folder'] . $cards['current']['attachment'];
	}
	if (isset($cards['previous']['attachment']) && !empty($cards['previous']['attachment'])) {
		
		$cards['previous']['imageURL'] = $config->baseurl . $_SESSION['game']['image_folder'] . $cards['previous']['attachment'];
	}
	// If game ended inform that
	if ($game->game_ended) {
		$cards['game_ended'] = true;
	}
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($cards);
	exit;
}

/**
* Function to save players answer and return result according to that.
* Needs $_POST['choice_id'] and $_SESSION['game_object'].
* @return JSON response containing result as an array.
*/
function save_choice_and_return_result_json() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$choice_id = 0;
	if (isset($_POST['choice_id'])) {
		$choice_id = doubleval($_POST['choice_id']);
	}
	$game;
	if (isset($_SESSION['game_object'])) {
		$game = $_SESSION['game_object'];
	}
	$result = array();
	$result = $game->getCardResult($choice_id);
	
	$profile_id = 0;
	if (isset($_POST['profile_id'])) {
		$profile_id = doubleval($_POST['profile_id']);
	}
	$stats = get_profile_stats($profile_id);
	
	$text = '';
	if ($result['result_text']) {
		$text = $result['result_text'];
	}
	else {
		$text = $result['default_text'];
	}
	// Replace stat based tags
	$modified_text = generate_dynamic_text($text, $stats);
	// Replace player name tag
	$modified_text = replace_player_name($modified_text, $profile_id);
	
	if ($result['result_text']) {
		$result['result_text'] = $modified_text;
	}
	else {
		$result['default_text'] = $modified_text;
	}
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($result);
	exit;
}

/**
* Function to get card information as JSON.
* Needs $_GET['card_id'].
* @return JSON response containing card as an array.
*/
function card_to_json() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	$current_lang = '';
	if (isset($_GET['language_code'])) {
		$current_lang = $_GET['language_code'];
	}
	elseif (isset($_SESSION['card_display_lang'])) {
		$current_lang = $_SESSION['card_display_lang'];
	}
	elseif (isset($_SESSION['lang'])) {
		$current_lang = $_SESSION['lang'];
	}
	else {
		global $language;
		$current_lang = $language;
	}
	$card_id = 0;
	if (isset($_GET['card_id'])) {
		$card_id = doubleval($_GET['card_id']);
	}
	$card = $db->getCard($card_id, $current_lang);
	
	global $image_folder;
	$current_image_folder = $image_folder;
		
	if (isset($_SESSION['game']['image_folder']) && empty($_SESSION['game']['image_folder'])) {
		$_SESSION['game']['image_folder'] = str_replace('\\', '/', $image_folder);
		$current_image_folder = $_SESSION['game']['image_folder'];
	}
	elseif (isset($_SESSION['admin']['game']['image_folder']) && !empty($_SESSION['admin']['game']['image_folder'])) {
		$current_image_folder = $_SESSION['admin']['game']['image_folder'];
	}
	$config = Config::getInstance();
	if (isset($card['attachment']) && !empty($card['attachment'])) {
		
		$card['imageURL'] = $config->baseurl . $current_image_folder . $card['attachment'];
	}
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($card);
	exit;
}

/**
* Function to get information of multiple cards JSON.
* Needs an array of card ids $_GET['card_ids'].
* @return JSON response containing cards as an array.
*/
function multiple_cards_to_json() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	$current_lang = '';
	if (isset($_SESSION['card_display_lang'])) {
		$current_lang = $_SESSION['card_display_lang'];
	}
	elseif (isset($_SESSION['lang'])) {
		$current_lang = $_SESSION['lang'];
	}
	else {
		global $language;
		$current_lang = $language;
	}
	$card_ids = array();
	$cards = array();
	if (isset($_GET['card_ids'])) {
		$card_ids = $_GET['card_ids'];
	}
	foreach ($card_ids as &$id) {
		$id = doubleval($id);
		$card = $db->getCard($id, $current_lang);
		if (!empty($card)) {
			$cards[] = $card;
		}
	}
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($cards);
	exit;
}

/**
* Function to get information of multiple cards as html.
* Needs an array of card ids $_GET['card_ids'].
* Used in admins compare cards view.
* @return HTML table containing cards.
*/
function multiple_cards_to_html() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	$current_lang = '';
	if (isset($_SESSION['card_display_lang'])) {
		$current_lang = $_SESSION['card_display_lang'];
	}
	elseif (isset($_SESSION['lang'])) {
		$current_lang = $_SESSION['lang'];
	}
	else {
		global $language;
		$current_lang = $language;
	}
	$card_ids = array();
	$cards = array();
	if (isset($_GET['card_ids'])) {
		$card_ids = $_GET['card_ids'];
	}
	foreach ($card_ids as &$id) {
		$id = doubleval($id);
		$card = $db->getCard($id, $current_lang);
		if (!empty($card)) {
			$cards[] = $card;
		}
	}
	unset($card);
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: text/html; charset=utf-8');
	
	echo('<table class="editor_table" id="compare_cards_table">' . PHP_EOL);
	echo('<thead class="editor_table_header">' . PHP_EOL);
	echo('<tr>' . PHP_EOL . '<th>' . localize("ADMIN_EDITOR_CARD_NAME") . '</th>' . PHP_EOL);
	// HEADER
	foreach ($cards as $card) {
		echo('<th>');
		if (isset($card['card_name']) && !empty($card['card_name'])) {
			echo($card['card_name']);
		}
		else {
			echo($card['default_name']);
		}
		echo('</th>' . PHP_EOL);
	}
	unset($card);
	echo('</tr>' . PHP_EOL . '</thead>' . PHP_EOL);
	echo('<tbody class="editor_table_body">' . PHP_EOL);
	// CONTENT
	echo('<tr><td class="admin_compare_cards_heading">' . localize('ADMIN_EDITOR_CARD_ID') . '</td>');
	foreach ($cards as $card) {
		echo('<td>');
		if (isset($card['card_external_id'])) {
			echo('<a id="compare_edit_card_' . $card['card_id'] . '" class="compare_edit_card_link" href="#">' . $card['card_external_id'] . '</a>');
		}
		echo('</td>' . PHP_EOL);
	}
	unset($card);
	echo('</tr>' . PHP_EOL);
	echo('<tr><td class="admin_compare_cards_heading">' . localize('ENABLED') . '</td>');
	foreach ($cards as $card) {
		echo('<td>');
		if (isset($card['enabled']) && $card['enabled']) {
			echo localize('YES');
		}
		else {
			echo localize('NO');
		}
		echo('</td>' . PHP_EOL);
	}
	unset($card);
	echo('</tr>' . PHP_EOL);
	echo('<tr><td class="admin_compare_cards_heading">' . localize('REPETITIVE') . '</td>');
	foreach ($cards as $card) {
		echo('<td>');
		if (isset($card['repetitive']) && $card['repetitive']) {
			echo localize('YES');
		}
		else {
			echo localize('NO');
		}
		echo('</td>' . PHP_EOL);
	}
	unset($card);
	echo('</tr>' . PHP_EOL);
	echo('<tr><td class="admin_compare_cards_heading">' . localize('ADMIN_EDITOR_CARD_LAYOUT') . '</td>');
	foreach ($cards as $card) {
		echo('<td>');
		if (isset($card['layout'])) {
			echo $card['layout'];
		}
		else {
			echo 'normal';
		}
		echo('</td>' . PHP_EOL);
	}
	unset($card);
	echo('</tr>' . PHP_EOL);
	echo('<tr><td class="admin_compare_cards_heading">' . localize('ADMIN_EDITOR_CARD_STATS') . '</td>');
	foreach ($cards as $card) {
		echo('<td>');
		if (isset($card['stat_requirements']) && !empty($card['stat_requirements'])) {
			foreach ($card['stat_requirements'] as $stat) {
				echo($stat . ' ');
			}
		}
		else {
			echo 'N/A';
		}
		echo('</td>' . PHP_EOL);
	}
	unset($card);
	echo('</tr>' . PHP_EOL);
	echo('<tr><td class="admin_compare_cards_heading">' . localize('ADMIN_EDITOR_CARD_TAGS') . '</td>');
	foreach ($cards as $card) {
		echo('<td>');
		if (isset($card['tags']) && !empty($card['tags'])) {
			foreach ($card['tags'] as $tag) {
				echo('#' . $tag . ' ');
			}
		}
		else {
			echo 'N/A';
		}
		echo('</td>' . PHP_EOL);
	}
	unset($card);
	echo('</tr>' . PHP_EOL);
	echo('<tr><td class="admin_compare_cards_heading">' . localize('ADMIN_EDITOR_CARD_COMMENT') . '</td>');
	foreach ($cards as $card) {
		echo('<td>');
		if (isset($card['comment']) && !empty($card['comment'])) {
			echo($card['comment']);
		}
		else {
			echo 'N/A';
		}
		echo('</td>' . PHP_EOL);
	}
	unset($card);
	echo('</tr>' . PHP_EOL);
	echo('<tr><td class="admin_compare_cards_heading">' . localize('ADMIN_EDITOR_CARD_PICTURE_LINK') . '</td>');
	foreach ($cards as $card) {
		echo('<td>');
		if (isset($card['attachment']) && !empty($card['attachment'])) {
			echo($card['attachment']);
		}
		else {
			echo 'N/A';
		}
		echo('</td>' . PHP_EOL);
	}
	unset($card);
	echo('</tr>' . PHP_EOL);
	echo('<tr><td class="admin_compare_cards_heading">' . localize('ADMIN_EDITOR_CARD_DEFAULT_LANGUAGE') . '</td>');
	foreach ($cards as $card) {
		echo('<td>');
		if (isset($card['default_lang']) && !empty($card['default_lang'])) {
			echo($card['default_lang']);
		}
		else {
			echo 'N/A';
		}
		echo('</td>' . PHP_EOL);
	}
	unset($card);
	echo('</tr>' . PHP_EOL);
	echo('<tr><td class="admin_compare_cards_heading">' . localize('ADMIN_EDITOR_CARD_TRANSLATIONS') . '</td>');
	foreach ($cards as $card) {
		echo('<td>');
		$translations = $db->getCardTranslations($card['card_id']);
		$trans_string = '';
		if (!empty($translations)) {
			foreach($translations as $trans) {
				$trans_string .= $trans['language_code'] . ', ';
			}
			$trans_string = substr($trans_string, 0, -2);
			echo $trans_string;
		}
		else {
			echo 'N/A';
		}
		echo('</td>' . PHP_EOL);
	}
	unset($card);
	echo('</tr>' . PHP_EOL);
	echo('<tr>' . PHP_EOL . '<td class="admin_compare_cards_heading">' . localize("ADMIN_EDITOR_CARD_DESCRIPTION") . '</td>' . PHP_EOL);
	foreach ($cards as $card) {
		echo('<td>');
		if (isset($card['description']) && !empty($card['description'])) {
			echo($card['description']);
		}
		else {
			echo($card['default_description']);
		}
		echo('</td>' . PHP_EOL);
	}
	unset($card);
	echo('</tr>' . PHP_EOL);
	echo('<tr>' . PHP_EOL . '<td class="admin_compare_cards_heading">' . localize("ADMIN_EDITOR_CARD_EXPERT_ADVICE") . '</td>' . PHP_EOL);
	foreach ($cards as $card) {
		echo('<td>');
		if (isset($card['expert_advice']) && !empty($card['expert_advice'])) {
			echo($card['expert_advice']);
		}
		else {
			echo($card['default_expert_advice']);
		}
		echo('</td>' . PHP_EOL);
	}
	unset($card);
	echo('</tr>' . PHP_EOL);
	$max_choices = 0;
	$max_results = array();
	
	$choice_counter = 0;
	// First get the maximum number of choices and card results
	foreach ($cards as &$card) {
		
		$card['results'] = array();
		
		if (isset($card['choices']) && !empty($card['choices'])) {
			if ($max_choices < count($card['choices'])) {
				$max_choices = count($card['choices']);
			}
			$choice_counter = 0;
			// Get results of every choice
			foreach ($card['choices'] as $choice) {
				$results = $db->getChoiceResults($choice['choice_id'], $current_lang);
				$card['results'][$choice_counter] = $results;
				// Get maximum number of results
				if (isset($max_results[$choice_counter])) {
					if ($max_results[$choice_counter] < count($results)) {
						$max_results[$choice_counter] = count($results);
					}
				}
				else {
					$max_results[] = count($results);
				}
				$choice_counter++;
			}
			unset($choice);
		}
	}
	unset($card);
	
	for ($i = 0; $i < $max_choices; $i++) {
		
		echo('<tr class="admin_compare_cards_choice">' . PHP_EOL . '<td  class="admin_compare_cards_heading">' . localize("CHOICE") . ' ' . ($i+1) . '</td>' . PHP_EOL);
		foreach ($cards as $card) {
			echo('<td>');
			if (isset($card['choices'][$i])) {
				if (!empty($card['choices'][$i]['choice_text'])) {
					echo($card['choices'][$i]['choice_text']);
				}
				else {
					echo($card['choices'][$i]['default_text']);
				}
			}
			else {
				echo('N/A');
			}
			echo('</td>' . PHP_EOL);
			
		}
		echo('</tr>' . PHP_EOL);
		unset($card);
		
		// Print results
		for ($j = 0; $j < $max_results[$i]; $j++) {
			
			// Result text
			echo('<tr class="admin_compare_cards_result_hidden">' . PHP_EOL . '<td class="admin_compare_cards_heading">' . localize("APP_SIMULATION_RESULT") . ' ' . ($i+1) . '.' . ($j+1) . '</td>' . PHP_EOL);
			foreach ($cards as $card) {

				echo('<td>');
				if (isset($card['results'][$i][$j])) {
					if (!empty($card['results'][$i][$j]['result_text'])) {
						echo($card['results'][$i][$j]['result_text']);
					}
					else {
						echo($card['results'][$i][$j]['default_text']);
					}
				}
				else {
					echo('N/A');
				}
				echo('</td>' . PHP_EOL);
			}
			echo('</tr>' . PHP_EOL);
			unset($card);
			
			// Result weight
			echo('<tr class="admin_compare_cards_result_hidden">' . PHP_EOL . '<td class="admin_compare_cards_heading">' . localize("WEIGHT") . ' ' . ($i+1) . '.' . ($j+1) . '</td>' . PHP_EOL);
			foreach ($cards as $card) {

				echo('<td>');
				if (isset($card['results'][$i][$j])) {
					if (!empty($card['results'][$i][$j]['weight'])) {
						echo($card['results'][$i][$j]['weight'] . ' %');
					}
					else {
						echo('N/A');
					}
				}
				else {
					echo('N/A');
				}
				echo('</td>' . PHP_EOL);
			}
			echo('</tr>' . PHP_EOL);
			unset($card);
			
			// Result stat changes
			echo('<tr class="admin_compare_cards_result_hidden">' . PHP_EOL . '<td class="admin_compare_cards_heading">' . localize("ADMIN_EDITOR_CARD_STAT_CHANGES") . ' ' . ($i+1) . '.' . ($j+1) . '</td>' . PHP_EOL);
			foreach ($cards as $card) {

				echo('<td>');
				if (isset($card['results'][$i][$j])) {
					if (!empty($card['results'][$i][$j]['stat_changes'])) {
						echo($card['results'][$i][$j]['stat_changes']);
					}
					else {
						echo('N/A');
					}
				}
				else {
					echo('N/A');
				}
				echo('</td>' . PHP_EOL);
			}
			echo('</tr>' . PHP_EOL);
			unset($card);
			
			// Result next card criteria
			echo('<tr class="admin_compare_cards_result_hidden">' . PHP_EOL . '<td class="admin_compare_cards_heading">' . localize("ADMIN_EDITOR_CARD_NEXT_CRITERIA") . ' ' . ($i+1) . '.' . ($j+1) . '</td>' . PHP_EOL);
			foreach ($cards as $card) {

				echo('<td>');
				if (isset($card['results'][$i][$j])) {
					if (!empty($card['results'][$i][$j]['next_criteria'])) {
						echo($card['results'][$i][$j]['next_criteria']);
					}
					else {
						echo('N/A');
					}
				}
				else {
					echo('N/A');
				}
				echo('</td>' . PHP_EOL);
			}
			echo('</tr>' . PHP_EOL);
			unset($card);
		}
	}
	
	echo('<tr>' . PHP_EOL . '<td class="admin_compare_cards_heading">' . localize("ADMIN_EDITOR_EDIT_CARD") . '</td>' . PHP_EOL);
	foreach ($cards as $card) {
		echo('<td>');
		echo('<a id="compare_edit_card_' . $card['card_id'] . '" class="compare_edit_card_link" href="#">' . localize("EDIT") . '</a>');
		echo('</td>' . PHP_EOL);
	}
	echo('</tr>' . PHP_EOL);
	
	echo('</tbody>' . PHP_EOL . '</table>' . PHP_EOL);
	echo('<br /><br />' . PHP_EOL);
	exit;
}

/**
* Function to get information of limited number of cards JSON.
* Needs a number of cards to return at max $_GET['limit'] and offset id $_GET['offset_id'].
* @return JSON response containing cards as an array.
*/
function multiple_cards_with_limit_to_json() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	$current_lang = '';
	if (isset($_SESSION['card_display_lang'])) {
		$current_lang = $_SESSION['card_display_lang'];
	}
	elseif (isset($_SESSION['lang'])) {
		$current_lang = $_SESSION['lang'];
	}
	else {
		global $language;
		$current_lang = $language;
	}
	$game_id = 0;
	if (isset($_SESSION['admin']['game'])) {
		$game_id = $_SESSION['admin']['game']['game_id'];
	}
	elseif (isset($_SESSION['game'])) {
		$game_id = $_SESSION['game']['game_id'];
	}
	$limit = -1;
	if (isset($_GET['limit'])) {
		$limit = intval($_GET['limit']);
	}
	$offset_id = 0;
	if (isset($_GET['offset_id'])) {
		$offset_id = intval($_GET['offset_id']);
	}
	
	$cards = $db->getAllCards($game_id, $current_lang, false, false, $limit, $offset_id);
	$round = 0;
	if (isset($_GET['round'])) {
		$round = intval($_GET['round']);
	}
	foreach ($cards as &$card) {
		$card['date_created'] = date(localize('DATE_FORMAT'), strtotime($card['created']));
		$card['latest_edit'] = '';
		if (isset($card['modified']) && !empty($card['modified']) && isset($card['editor_name'])) {
			$card['latest_edit'] = date(localize('DATE_FORMAT'), strtotime($card['modified'])) . ' ' . $card['editor_name'];
		}
	}
	$response = array();
	$response['cards'] = $cards;
	$response['round'] = $round;
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($response);
	exit;
}

/**
* Function to get choices of a card as html.
* Needs an array of cards choices as $_GET['choices'] and information of is card previous or current as $_GET['position'].
* Used in simulation view.
* @return HTML buttons which represents choices.
*/
function card_choices_to_html() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	$choices = array();
	if (isset($_GET['choices'])) {
		$choices = $_GET['choices'];
	}
	$position = 'current';
	if (isset($_GET['position'])) {
		$position = $_GET['position'];
	}
	//$db = DB::getInstance();
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: text/html; charset=utf-8');
	
	foreach ($choices as $choice) {
		$choice_text = '';
		if (isset($choice['choice_text']) && !empty($choice['choice_text'])) {
			$choice_text = $choice['choice_text'];
		}
		elseif (isset($choice['default_text']) && !empty($choice['default_text'])) {
			$choice_text = $choice['default_text'];
		}
		echo('<button class="simulation_select_button select_' . $position . '" name="simulation_' . $position . '_choices" id="simulation_' . $position . '_choices_' . $choice['choice_id'] . '" value="' . $choice['choice_id'] . '">' . $choice_text . '</button>' . PHP_EOL);
	}
	exit;
}

/**
* Function to get choices and results of a card as html.
* Needs an array of cards choices as $_GET['choices'], $_GET['card_id'] and $_GET['new_or_edit'].
* Used in admin edit cards view.
* @return HTML elements for manipulating choices and results.
*/
function card_choices_and_results_to_html() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	$choices = array();
	if (isset($_GET['choices'])) {
		$choices = $_GET['choices'];
	}
	$db = DB::getInstance();
	$current_lang = '';
	if (isset($_GET['language_code'])) {
		$current_lang = $_GET['language_code'];
	}
	elseif (isset($_SESSION['card_display_lang'])) {
		$current_lang = $_SESSION['card_display_lang'];
	}
	elseif (isset($_SESSION['lang'])) {
		$current_lang = $_SESSION['lang'];
	}
	else {
		global $language;
		$current_lang = $language;
	}
	$new_or_edit = 'edit_card';
	if (isset($_GET['new_or_edit'])) {
		$new_or_edit = $_GET['new_or_edit'];
	}
	$card_id = 0;
	if (isset($_GET['card_id'])) {
		$card_id = doubleval($_GET['card_id']);
	}
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: text/html; charset=utf-8');
	
	$choices_counter = 0;
	do {
		echo('<div id="' . $new_or_edit . '[choices][' . $choices_counter . ']" class="result_div">' . PHP_EOL);
		echo('<br />' . PHP_EOL);
		echo('<span class="label_with_input">' . PHP_EOL);
		$choice_text = '';
		if (isset($choices[$choices_counter]['choice_text']) && !empty($choices[$choices_counter]['choice_text'])) {
			$choice_text = $choices[$choices_counter]['choice_text'];
		}
		else {
			 $choice_text = $choices[$choices_counter]['default_text'];
		}
		echo('	<label class="top" for="' . $new_or_edit . '[choices][' . $choices_counter . '][text]">' . ($choices_counter+1) . '. </label><textarea class="" name="' . $new_or_edit . '[choices][' . $choices_counter . '][text]" id="' . $new_or_edit . '[choices][' . $choices_counter . '][text]" >' . $choice_text . '</textarea>' . PHP_EOL);
		// Remove choice button
		if ($choices_counter > 0) {
			echo('	<button class="remove_choice_button" id="' . $new_or_edit . '[remove_choice_' . $choices_counter . ']" name="edit_card[remove_choice_' . $choices_counter . ']">' . localize('ADMIN_EDITOR_REMOVE_CHOICE') . '</button>' . PHP_EOL);
		}
		echo('</span>' . PHP_EOL);
		echo('<br />' . PHP_EOL);
		echo('<div class="results" id="' . $new_or_edit . '[results_' . $choices_counter . ']">' . PHP_EOL);
		$results_counter = 0;
		$results = $db->getChoiceResults($choices[$choices_counter]['choice_id'], $current_lang);
		
		do {
			$result_weight = $results[$results_counter]['weight'];
			$result_stat_changes = $results[$results_counter]['stat_changes'];
			$result_next_criteria = $results[$results_counter]['next_criteria'];
			$result_text = '';
			if (isset($results[$results_counter]['result_text']) && !empty($results[$results_counter]['result_text'])) {
				$result_text = $results[$results_counter]['result_text'];
			}
			else {
				$result_text = $results[$results_counter]['default_text'];
			}
			echo('	<div id="' . $new_or_edit . '[result_' . $choices_counter . '_' . $results_counter . ']">' . PHP_EOL);
			echo('	<br />' . PHP_EOL);
			echo('	<span class="label_with_input">' . PHP_EOL);
			echo('		<label for="' . $new_or_edit . '[results][' . $choices_counter . '][' . $results_counter . '][weight]">' . ($choices_counter+1) . '.' . ($results_counter+1) . '</label>' . PHP_EOL);
			echo('		<input class="percent_input" type="text" name="' . $new_or_edit . '[results][' . $choices_counter . '][' . $results_counter . '][weight]" id="' . $new_or_edit . '[results][' . $choices_counter. '][' . $results_counter . '][weight]" value="' . $result_weight . '" />' . PHP_EOL);
			echo('  %  ');
			// Remove result button
			if ($results_counter > 0) {
				echo('<button class="remove_result_button" id="' . $new_or_edit . '[remove_result_' . $choices_counter . '_' . $results_counter . ']" name="' . $new_or_edit . '[remove_result_' . $choices_counter . '_' . $results_counter . ']">' . localize('ADMIN_EDITOR_REMOVE_RESULT') . '</button>' . PHP_EOL);
			}
			echo('</span>' . PHP_EOL);
			echo('	<br /><textarea class="game_settings_intended" name="' . $new_or_edit . '[results][' . $choices_counter . '][' . $results_counter . '][text]" id="' . $new_or_edit . '[results][' . $choices_counter . '][' . $results_counter . '][text]">' . $result_text . '</textarea>' . PHP_EOL);
			echo('	<br />' . PHP_EOL);
			echo('		<label class="game_settings_intended" for="' . $new_or_edit . '[results][' . $choices_counter . '][' . $results_counter . '][stat_changes]">' . localize('ADMIN_EDITOR_CARD_STAT_CHANGES') . ': </label><br /><input class="autocomplete_stats game_settings_intended" type="text" name="' . $new_or_edit . '[results][' . $choices_counter . '][' . $results_counter . '][stat_changes]" id="' . $new_or_edit . '[results][' . $choices_counter . '][' . $results_counter . '][stat_changes]" value="' . $result_stat_changes . '" />' . PHP_EOL);
			echo('	<br />' . PHP_EOL);
			echo('		<label class="game_settings_intended" for="' . $new_or_edit . '[results][' . $choices_counter . '][' . $results_counter . '][next_criteria]">' . localize('ADMIN_EDITOR_CARD_NEXT_CRITERIA') . ': </label><br /><input class="autocomplete_tags game_settings_intended" type="text" name="' . $new_or_edit . '[results][' . $choices_counter . '][' . $results_counter . '][next_criteria]" id="' . $new_or_edit . '[results][' . $choices_counter . '][' . $results_counter . '][next_criteria]" value="' . $result_next_criteria . '" />' . PHP_EOL);
			echo('	<br />' . PHP_EOL);
			echo('	</div>' . PHP_EOL);
			$results_counter++;
		} while (isset($results[$results_counter]['result_text']) || isset($results[$results_counter]['default_text']));
		echo('	<button class="new_result_button" id="' . $new_or_edit . '[add_new_result_' . ($results_counter - 1) . ']" name="' . $new_or_edit . '[add_new_result_' . ($results_counter-1) . ']">' . localize('ADMIN_EDITOR_ADD_RESULT') . '</button>' . PHP_EOL);
		echo('</div>' . PHP_EOL);
		echo('</div>' . PHP_EOL);
		$choices_counter++;
	} while (isset($choices[$choices_counter]['choice_text']) || isset($choices[$choices_counter]['default_text']));	
	exit;
}

/**
* Function to get new result to card as html.
* Needs 'new_card' or 'edit_card' in $_GET['new_or_edit'], $_GET['result_id'] and $_GET['choice_id'].
* Used in admin create or edit card view.
* @return HTML elements that represents new result.
*/
function print_new_result() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	$result_id = 0;
	if (isset($_GET['result_id'])) {
		$result_id = intval($_GET['result_id']);
	}
	$choice_id = 0;
	if (isset($_GET['choice_id'])) {
		$choice_id = intval($_GET['choice_id']);
	}
	$new_or_edit = 'new_card';
	if (isset($_GET['new_or_edit'])) {
		$new_or_edit = $_GET['new_or_edit'];
	}
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: text/html; charset=utf-8');
	echo('	<div id="' . $new_or_edit . '[result_' . $choice_id . '_' . $result_id . ']">' . PHP_EOL);
	echo('<br />' . PHP_EOL);
	echo('<span class="label_with_input">' . PHP_EOL);
	echo('	<label for="' . $new_or_edit . '[results][' . $choice_id . '][' . $result_id . '][weight]">');
	echo(($choice_id+1) . '.' . ($result_id+1) . '</label>' . PHP_EOL);
	echo('	<input class="percent_input" type="text" name="' . $new_or_edit . '[results][' . $choice_id . '][' . $result_id . '][weight]" id="' . $new_or_edit . '[results][' . $choice_id . '][' . $result_id . '][weight]" value="" />' . PHP_EOL);				
	echo('% ');
	// Remove result button
	if ($result_id > 0) {
		echo('	<button class="remove_result_button" id="' . $new_or_edit . '[remove_result_' . $choice_id . '_' . $result_id . ']" name="' . $new_or_edit . '[remove_result_' . $choice_id . '_' . $result_id . ']">' . localize('ADMIN_EDITOR_REMOVE_RESULT') . '</button>' . PHP_EOL);
	}
	echo('</span>' . PHP_EOL);
	echo('<br /><textarea class="game_settings_intended" name="' . $new_or_edit . '[results][' . $choice_id . '][' . $result_id . '][text]" id="' . $new_or_edit . '[results][' . $choice_id . '][' . $result_id . '][text]"></textarea>' . PHP_EOL); //value="" /></span>' . PHP_EOL);
	echo('<br />' . PHP_EOL);
	echo('<label class="game_settings_intended" for="' . $new_or_edit . '[results][' . $choice_id . '][' . $result_id . '][stat_changes]">' . localize('ADMIN_EDITOR_CARD_STAT_CHANGES') . ': </label><br /><input class="autocomplete_stats game_settings_intended" type="text" name="' . $new_or_edit . '[results][' . $choice_id . '][' . $result_id . '][stat_changes]" id="' . $new_or_edit . '[results][' . $choice_id . '][' . $result_id . '][stat_changes]" value="" />' . PHP_EOL);
	echo('<br />' . PHP_EOL);
	echo('<label class="game_settings_intended" for="' . $new_or_edit . '[results][' . $choice_id . '][' . $result_id . '][next_criteria]">' . localize('ADMIN_EDITOR_CARD_NEXT_CRITERIA') . ': </label><br /><input class="autocomplete_tags game_settings_intended" type="text" name="' . $new_or_edit . '[results][' . $choice_id . '][' . $result_id . '][next_criteria]" id="' . $new_or_edit . '[results][' . $choice_id . '][' . $result_id . '][next_criteria]" value="" />' . PHP_EOL);
	echo('<br />' . PHP_EOL);
	echo('</div>' . PHP_EOL);
	echo('<button class="new_result_button" id="' . $new_or_edit . '[add_new_result_' . $result_id . ']" name="' . $new_or_edit . '[add_new_result_' . $result_id . ']">' . localize('ADMIN_EDITOR_ADD_RESULT'). '</button>' . PHP_EOL);
	exit;
}

/**
* Function to get new choice to card as html.
* Needs 'new_card' or 'edit_card' in $_GET['new_or_edit'] and $_GET['choice_id'].
* Used in admin create or edit card view.
* @return HTML elements that represents a new choice.
*/
function print_new_choice() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$choice_id = 0;
	if (isset($_GET['choice_id'])) {
		$choice_id = intval($_GET['choice_id']);
	}
	$new_or_edit = 'new_card';
	if (isset($_GET['new_or_edit'])) {
		$new_or_edit = $_GET['new_or_edit'];
	}
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: text/html; charset=utf-8');
	
	echo('<div id="' . $new_or_edit . '[choices][' . $choice_id . ']" class="result_div">' . PHP_EOL);
	echo('<br />' . PHP_EOL);
	echo('<span class="label_with_input">' . PHP_EOL);
	echo('	<label class="top" for="' . $new_or_edit . '[choices][' . $choice_id . '][text]">' . ($choice_id+1) . '. </label><textarea class="" name="' . $new_or_edit . '[choices][' . $choice_id . '][text]" id="' . $new_or_edit . '[choices][' . $choice_id . '][text]"></textarea>' . PHP_EOL);
	// Remove choice button
	if ($choice_id > 0) {
		echo('	<button class="remove_choice_button" id="' . $new_or_edit . '[remove_choice_' . $choice_id . ']" name="' . $new_or_edit . '[remove_choice_' . $choice_id . ']">' . localize('ADMIN_EDITOR_REMOVE_CHOICE') . '</button>' . PHP_EOL);
	}
	echo('</span>' . PHP_EOL);
	echo('<br />' . PHP_EOL);
	echo('<div class="results" id="' . $new_or_edit . '[results_' . $choice_id . ']">' . PHP_EOL);
	echo('</div>' . PHP_EOL);
	echo('</div>');
	exit;
}

/**
* Function to get new condition to game settings as html.
* Needs 'sudden_scenarios' or 'ending_criteria' in $_GET['setting_name'] and $_GET['option_id'], $_GET['condition_id'].
* Used in admin game settings view.
* @return HTML elements that represents a new condition.
*/
function print_new_condition() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	$option_id = 0;
	if (isset($_GET['option_id'])) {
		$option_id = intval($_GET['option_id']);
	}
	$condition_id = 0;
	if (isset($_GET['condition_id'])) {
		$condition_id = intval($_GET['condition_id']);
	}
	$setting_name = 'sudden_scenarios';
	if (isset($_GET['setting_name'])) {
		$setting_name = $_GET['setting_name'];
	}
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: text/html; charset=utf-8');
	
	echo('<div id="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][conditions][' . $condition_id . ']">' . PHP_EOL);
	echo('	<input class="autocomplete_stats" type="text" name="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][conditions][' . $condition_id . '][condition_text]" id="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][conditions][' . $condition_id . '][condition_text]" value="" />' . PHP_EOL);
	if ($setting_name == 'sudden_scenarios') {
		echo('	<select class="admin_editor_settings_select_scenario_condition_logic" name="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][conditions][' . $condition_id . '][condition_logic]" id="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][conditions][' . $condition_id . '][condition_logic]" >' . PHP_EOL);
	}
	else {
		echo('	<select class="admin_editor_settings_select_ending_condition_logic" name="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][conditions][' . $condition_id . '][condition_logic]" id="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][conditions][' . $condition_id . '][condition_logic]" >' . PHP_EOL);
	}
	echo('		<option value="" selected="selected"> </option>' . PHP_EOL);
	echo('		<option value="AND">' . localize("AND") . '</option>' . PHP_EOL);
	echo('		<option value="OR">' . localize("OR") . '</option>' . PHP_EOL);
	echo('	</select>' . PHP_EOL);
	echo('</div>' . PHP_EOL);
	exit;
}

/**
* Function to get new option in game settings as html.
* Needs 'sudden_scenarios' or 'ending_criteria' in $_GET['setting_name'] and $_GET['option_id'].
* Used in admin game settings view.
* @return HTML elements that represents a new option.
*/
function print_new_option() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$option_id = 0;
	if (isset($_GET['option_id'])) {
		$option_id = intval($_GET['option_id']);
	}
	$condition_id = 0;
	
	$setting_name = 'sudden_scenarios';
	if (isset($_GET['setting_name'])) {
		$setting_name = $_GET['setting_name'];
	}
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: text/html; charset=utf-8');
	echo('<span id="' . $setting_name . '_' . $option_id . '" class="game_settings_option">' . PHP_EOL);
	echo('<label>' . ($option_id+1) . '. ' . localize('ADMIN_EDITOR_GAME_SETTINGS_IF') . '</label>' . PHP_EOL);
	echo('<div class="game_settings_intended" id="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][conditions]">' . PHP_EOL);
	echo('	<div id="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][conditions][0]">' . PHP_EOL);
	echo('		<input class="autocomplete_stats" type="text" name="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][conditions][' . $condition_id . '][condition_text]" id="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][conditions][' . $condition_id . '][condition_text]" value="" />' . PHP_EOL);
	if ($setting_name == 'sudden_scenarios') {
		echo('		<select class="admin_editor_settings_select_scenario_condition_logic" name="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][conditions][' . $condition_id . '][condition_logic]" id="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][conditions][' . $condition_id . '][condition_logic]" >' . PHP_EOL);
	}
	else {
		echo('		<select class="admin_editor_settings_select_ending_condition_logic" name="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][conditions][' . $condition_id . '][condition_logic]" id="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][conditions][' . $condition_id . '][condition_logic]" >' . PHP_EOL);
	}
	echo('			<option value="" selected="selected"> </option>' . PHP_EOL);
	echo('			<option value="AND">' . localize("AND") . '</option>' . PHP_EOL);
	echo('			<option value="OR">' . localize("OR") . '</option>' . PHP_EOL);
	echo('		</select>' . PHP_EOL);
	echo('	</div>' . PHP_EOL);
	echo('</div>' . PHP_EOL);
	echo('<div class="game_settings_intended">' . PHP_EOL);
	if ($setting_name == 'sudden_scenarios') {
		echo localize('ADMIN_EDITOR_GAME_SETTINGS_THEN');
		echo(' <input class="percent_input" type="text" name="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][odds]" id="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][odds]" value="" />');
		echo(localize('ADMIN_EDITOR_GAME_SETTINGS_CHANGE_OF_DISPLAYING') . PHP_EOL);
	}
	else {
		echo(localize('ADMIN_EDITOR_GAME_SETTINGS_THEN_GO_TO') . PHP_EOL);
	}
	echo('		<br /><input class="autocomplete_tags" type="text" name="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][result]" id="editor[settings][' . $setting_name . '_definitions][' . $option_id . '][result]" value="" />' . PHP_EOL);
	echo('		<button id="delete_' . $setting_name . '_' . $option_id . '" class="delete_option_button">' . localize('DELETE') . '</button>' . PHP_EOL);
	
	echo('</div>' . PHP_EOL);
	echo('<br />' . PHP_EOL);
	echo('</span>' . PHP_EOL);
	exit;
}

/**
* Function to get translations of a card as JSON.
* Needs $_GET['card_id'].
* @return JSON response containing translations of a card.
*/
function card_translations_to_json() {

	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	$db = DB::getInstance();
	$card_id = 0;
	if (isset($_GET['card_id'])) {
		$card_id = doubleval($_GET['card_id']);
	}
	$translations = $db->getCardTranslations($card_id);
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($translations);
	exit;
}

/**
* Function to get translations of a card as html for select element.
* Needs $_GET['card_id'].
* @return HTML option elements which represents translations.
*/
function card_translations_to_html() {

	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	$card_id = 0;
	if (isset($_GET['card_id'])) {
		$card_id = doubleval($_GET['card_id']);
	}
	$translations = $db->getCardTranslations($card_id);
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: text/html; charset=utf-8');
	
	foreach($translations as $trans) {
		echo('<option value="' . $trans['language_code'] . '">' . $trans['language_code'] . '</option>' . PHP_EOL);
	}
	exit;
}

/**
* Function to add a new translation for a card.
* Needs $_GET['card_id'] and $_POST['language_code'].
* @return void
*/
function add_new_translation() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	$card_id = 0;
	if (isset($_POST['card_id'])) {
		$card_id = doubleval($_POST['card_id']);
	}
	$language_code = '';
	if (isset($_POST['language_code'])) {
		$language_code = $_POST['language_code'];
	}
	
	$debug = $card_id . ' ' . $language_code;
	
	if ($card_id > 0 && $language_code != '') {
		$card = $db->getCard($card_id);
		
		if (!empty($card)) {
		
			$trans_id = $db->addCardTranslation($card_id, $card['default_name'], $card['default_description'], $card['default_expert_advice'], $language_code, 0);
			
			foreach ($card['choices'] as $choice) {
				
				$trans_id = $db->addChoiceTranslation($choice['choice_id'], $choice['default_text'], $language_code, 0, $card_id);
				$results = $db->getChoiceResults($choice['choice_id']);
				
				foreach ($results as $result) {
					$trans_id = $db->addResultTranslation($result['result_id'], $result['default_text'], $language_code, 0, $card_id);
				}
			}
		}
	}
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: text/html; charset=utf-8');
	exit;
}

/**
* Function to get played cards as html.
* Needs $_GET['profile_id'].
* Used in admin player profiles view.
* @return HTML tr and td elements which represents played cards, choices and results.
*/
function played_cards_to_html() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	$profile_id = 0;
	if (isset($_GET['profile_id'])) {
		$profile_id = doubleval($_GET['profile_id']);
	}
	
	$played_cards = $db->getPlayedCards($profile_id);
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: text/html; charset=utf-8');
	$counter = 1;
	foreach($played_cards as $card) {
		echo('<tr>' . PHP_EOL);
		$temp_card = $db->getCard($card['card_id']);
		$card_external_id = $temp_card['card_external_id'];
		echo('	<td>' . $card_external_id . '</td>' . PHP_EOL);
		$choice_ordinal = 0;
		$result_ordinal = 0;
		$stat_changes = '';
		
		if ($card['choice_id'] > 0) {
			$result = $db->getResult($card['result_id']);
			
			if (!empty($result)) {
				$choice_ordinal = $result['choice_ordinal'];
				$result_ordinal = $result['ordinal'];
				$stat_changes = $result['stat_changes'];
			}
		}
		//$choice_and_result = '';
		$choice_and_result = $card_external_id;
		
		if ($choice_ordinal > 0) {
			//$choice_and_result .= $card_external_id . '.' . $choice_ordinal;
			$choice_and_result .= '.' . $choice_ordinal;
			if ($result_ordinal > 0) {
				$choice_and_result .= '.' . $result_ordinal;
			}
		}
		echo('	<td><a href="#" id="' . $counter . '_played_card_' . $card['card_id'] . '_choice_' . $card['choice_id'] . '_result_' . $card['result_id'] . '" class="show_played_card_choice_result">' . $choice_and_result . '</a></td>' . PHP_EOL);
		echo('	<td>' . $stat_changes . '</td>' . PHP_EOL);
		echo('</tr>' . PHP_EOL);
		$counter++;
	}
	exit;
}

/**
* Function to get player stats as html.
* Needs $_GET['profile_id'] and optionally $_GET['header'].
* Used in simulation view header and admin player profiles view.
* @return Different HTML elements depending of if $_GET['header'] is true which represents stats.
*/
function player_stats_to_html() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$profile_id = 0;
	if (isset($_GET['profile_id'])) {
		$profile_id = doubleval($_GET['profile_id']);
	}

	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: text/html; charset=utf-8');
	
	$stats = get_profile_stats($profile_id);
	
	if (isset($_GET['header'])) {
		
		$visible_stats = array();
		if (isset($_SESSION['game']['visible_stats'])) {
			$visible_stats = $_SESSION['game']['visible_stats'];
		}
		
		echo('<dl>');
		
		if (!empty($visible_stats)) {
            			
			$stat_names = array_keys($stats);
			$stat_values = array_values($stats);
            			
			foreach ($visible_stats as $stat) {
            				
				$index = array_search($stat, $stat_names);
				if ($index !== false) {
					$stat_temp = $stat_values[$index];
					if ($stat_temp[0] == '=') {
						$stat_temp = substr($stat_temp, 1);
					}
					echo('<dt>' . $stat. '</dt><dd>' . $stat_temp . '</dd>' . PHP_EOL);
				}
				else {
					echo('<dt>' . $stat. '</dt><dd>-</dd>' . PHP_EOL);
				}
			}
		}
		else {
			echo('<dt>&nbsp;</dt><dd>&nbsp;</dd>' . PHP_EOL);
		}
		echo('</dl>');
	}
	else {
		echo('<div>');
		foreach ($stats as $stat => $value) {
			$stat_val = '';
			$pos = strrpos($value, "=");
			if ($pos !== false) {
				$stat_val = $value;
			}
			elseif (doubleval($value) > 0) {
				$stat_val = '+' . $value;
			}
			elseif (doubleval($value) < 0) {
				$stat_val = $value;
			}
			elseif (doubleval($value) != 0) {
				$stat_val = '=' . $value;
			}
			echo('@' . $stat . $stat_val . '<br />' . PHP_EOL);
		}
		echo('</div>');
	}
	exit;
}

/**
* Function to get player stats as JSON.
* Needs $_GET['profile_id'].
* @return JSON response of player's stats as key-value pairs.
*/
function player_stats_to_json() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$profile_id = 0;
	if (isset($_GET['profile_id'])) {
		$profile_id = doubleval($_GET['profile_id']);
	}
	
	$stats = get_profile_stats($profile_id);
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($stats);
	exit;
}

/**
* Function to enable or disable card.
* Needs $_POST['card_id'] and bool $_POST['enable'].
* @return void
*/
function enable_disable_card() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	$card_id = 0;
	if (isset($_POST['card_id'])) {
		$card_id = doubleval($_POST['card_id']);
	}
	$enabled = 1;
	if (isset($_POST['enable'])) {
		if ($_POST['enable'] == 1) {
			$enabled = 1;
		}
		else {
			$enabled = 0;
		}
	}
	$db->enable_disable_card(doubleval($card_id), intval($enabled));
	exit;
}

/**
* Function to delete card.
* Needs $_POST['card_id'].
* @return void
*/
function delete_card() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	$card_id = 0;
	if (isset($_POST['card_id'])) {
		$card_id = doubleval($_POST['card_id']);
	}
	$db->deleteCard($card_id);
	$response = array();
	$response['deleted_card'] = $card_id;
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($response);
	exit;
}

/**
* Function to delete profile.
* Needs $_POST['profile_id'].
* @return JSON response with 'deleted_profile' containing profile_id
*/
function delete_profile() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	$profile_id = 0;
	if (isset($_POST['profile_id'])) {
		$profile_id = doubleval($_POST['profile_id']);
	}
	$db->deleteProfile($profile_id);
	
	$current_profile = -1;
	$response = array();
	// If current profile is deleted mark that flag true and unset game
	if (isset($_SESSION['game']['profile']) && $_SESSION['game']['profile'] == $profile_id) {
		$response['current_profile_deleted'] = true;
		unset($_SESSION['game']);
	}
	$response['deleted_profile'] = $profile_id;
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($response);
	exit;
}

/**
* Function to change default display language for cards in admin editor.
* Needs $_GET['language_code'].
* @return JSON response with 'reload' containing if page needs to reload
*/
function change_card_display_lang() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	$reload = false;
	if (isset($_GET['language_code'])) {
		if (!isset($_SESSION['card_display_lang']) || $_SESSION['card_display_lang'] != $_GET['language_code']) {
			$reload = true;
			$_SESSION['card_display_lang'] = $_GET['language_code'];
		}
	}
	$response = array();
	$response['reload'] = $reload;
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($response);
	exit;
}

/**
* Function to get result information as JSON.
* Needs $_GET['result_id'].
* @return JSON response containing result as an array.
*/
function result_to_json() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	$current_lang = '';
	if (isset($_GET['language_code'])) {
		$current_lang = $_GET['language_code'];
	}
	elseif (isset($_SESSION['card_display_lang'])) {
		$current_lang = $_SESSION['card_display_lang'];
	}
	elseif (isset($_SESSION['lang'])) {
		$current_lang = $_SESSION['lang'];
	}
	else {
		global $language;
		$current_lang = $language;
	}
	$result_id = 0;
	if (isset($_GET['result_id'])) {
		$result_id = doubleval($_GET['result_id']);
	}
	$result = $db->getResult($result_id, $current_lang);
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($result);
	exit;
}

/**
* Function to get player profiles as JSON.
* Needs $_GET['from'] and $_GET['to'].
* @return JSON response containing profiles as an array, error message if any and count of profiles found.
*/
function player_profiles_to_json() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	$current_lang = '';
	if (isset($_GET['language_code'])) {
		$current_lang = $_GET['language_code'];
	}
	elseif (isset($_SESSION['card_display_lang'])) {
		$current_lang = $_SESSION['card_display_lang'];
	}
	elseif (isset($_SESSION['lang'])) {
		$current_lang = $_SESSION['lang'];
	}
	else {
		global $language;
		$current_lang = $language;
	}
	$game;
	if (isset($_SESSION['admin']['game'])) {
		$game = $_SESSION['admin']['game'];
	}
	$from_input = '';
	if (isset($_GET['from'])) {
		$from_input = $_GET['from'];
	}
	$to_input = '';
	if (isset($_GET['to'])) {
		$to_input = $_GET['to'];
	}
	
	$response = array();
	$response['error'] = '';
	$response['profiles'] = array();
	$response['profile_count'] = 0;
	
	$temp_from = explode('/', $from_input);
	$temp_to = explode('/', $to_input);
	
	if (count($temp_from) == 3 && count($temp_to) == 3) {
		
		$all_profiles = $db->getAllProfiles($game['game_id']);
		$from = date('Y-m-d H:i:s', strtotime($temp_from[2] . '-' .  $temp_from[0] . '-' . $temp_from[1]));
		$to = date('Y-m-d H:i:s', strtotime($temp_to[2] . '-' .  $temp_to[0] . '-' . $temp_to[1]));
		
		foreach ($all_profiles as $profile) {
			$created = strtotime($profile['created']);
			if ($created >= strtotime($from) && $created <= strtotime($to)) {
				$response['profiles'][] = $profile;
			}
		}
	}
	else {
		$response['error'] = localize('ERROR_ADMIN_EDITOR_INVALID_DATE');
	}
	
	$response['profile_count'] = count($response['profiles']);
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($response);
	exit;
}

/**
* Function to generate player profiles file and return filepath to that as JSON.
* Needs $_POST['from'] and $_POST['to'].
* @return JSON response containing filepath to player profiles file.
*/
function generate_profiles_file() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$db = DB::getInstance();
	$current_lang = '';
	if (isset($_GET['language_code'])) {
		$current_lang = $_GET['language_code'];
	}
	elseif (isset($_SESSION['card_display_lang'])) {
		$current_lang = $_SESSION['card_display_lang'];
	}
	elseif (isset($_SESSION['lang'])) {
		$current_lang = $_SESSION['lang'];
	}
	else {
		global $language;
		$current_lang = $language;
	}
	$game;
	if (isset($_SESSION['admin']['game'])) {
		$game = $_SESSION['admin']['game'];
	}
	$from_input = '';
	if (isset($_GET['from'])) {
		$from_input = $_GET['from'];
	}
	$to_input = '';
	if (isset($_GET['to'])) {
		$to_input = $_GET['to'];
	}
	$response = array();
	$response['error'] = '';
	$response['profile_count'] = 0;
	$temp_from = explode('/', $from_input);
	$temp_to = explode('/', $to_input);
	
	$profiles_to_write = array();
	
	if (count($temp_from) == 3 && count($temp_to) == 3) {
		
		$all_profiles = $db->getAllProfiles($game['game_id']);
		$from = date('Y-m-d H:i:s', strtotime($temp_from[2] . '-' .  $temp_from[0] . '-' . $temp_from[1]));
		$to = date('Y-m-d H:i:s', strtotime($temp_to[2] . '-' .  $temp_to[0] . '-' . $temp_to[1]));
		
		foreach ($all_profiles as $profile) {
			$created = strtotime($profile['created']);
			if ($created >= strtotime($from) && $created <= strtotime($to)) {
				$profiles_to_write[] = $profile;
			}
		}
		unset($profile);
		$response['profile_count'] = count($profiles_to_write);
	}
	else {
		$response['error'] = localize('ERROR_ADMIN_EDITOR_INVALID_DATE');
	}
	//$context = '"ID";"' . localize('ADMIN_EDITOR_PROFILE_CREATED') . '";"' . localize('ADMIN_EDITOR_PLAYER_NAME') . '";"' . localize('ADMIN_EDITOR_PROFILE_PLAYED_CARDS') . '"';
	$context = 'ID;' . localize('ADMIN_EDITOR_PROFILE_CREATED') . ';' . localize('ADMIN_EDITOR_PLAYER_NAME') . ';' . localize('ADMIN_EDITOR_PROFILE_PLAYED_CARDS');
	// Get maximum number of played cards to get the correct number of columns for csv file
	$max_played_cards = 0;
	foreach ($profiles_to_write as $profile) {
		$played_cards = 0;
		if ($profile['played_cards'] > 0) {
			$played_cards = $profile['played_cards'];
		}
		if ($max_played_cards < $played_cards) {
			$max_played_cards = $played_cards;
		}
	}
	unset($profile);
	for ($i = 1; $i <= $max_played_cards; $i++) {
		//$context .= ';"' . localize('CARD') . ' ' . $i . '"';
		$context .= ';' . localize('CARD') . ' ' . $i;
	}
	
	foreach ($profiles_to_write as $profile) {
		$played_cards = 0;
		if ($profile['played_cards'] > 0) {
			$played_cards = $profile['played_cards'];
		}
		$unwanted_chars = array('\r\n', '\n', '\r', '"', ';');
		//$context .= PHP_EOL . '"' . $profile['profile_id'] . '";"' . date(localize('DATE_FORMAT'), strtotime($profile['created'])) . '";"' . str_replace($unwanted_chars, '', $profile['player_name']) . '";"' . $played_cards . '"';
		$context .= PHP_EOL . $profile['profile_id'] . ';' . date(localize('DATE_FORMAT'), strtotime($profile['created'])) . ';' . str_replace($unwanted_chars, '', $profile['player_name']) . ';' . $played_cards;
		$played_cards = $db->getPlayedCards($profile['profile_id']);
		// Get played cards, choices and results
		$counter = 1;
		foreach($played_cards as $card) {
			$temp_card = $db->getCard($card['card_id']);
			$card_external_id = $temp_card['card_external_id'];
			$choice_ordinal = 0;
			$result_ordinal = 0;
		
			if ($card['choice_id'] > 0) {
				$result = $db->getResult($card['result_id']);
			
				if (!empty($result)) {
					$choice_ordinal = $result['choice_ordinal'];
					$result_ordinal = $result['ordinal'];
				}
			}
			$choice_and_result = $card_external_id;
		
			if ($choice_ordinal > 0) {
				$choice_and_result .= '.' . $choice_ordinal;
				if ($result_ordinal > 0) {
					$choice_and_result .= '.' . $result_ordinal;
				}
			}
			//$context .= ';"' . $choice_and_result . '"';
			$context .= ';' . $choice_and_result;
		}
		for ($j = count($played_cards); $j < $max_played_cards; $j++) {
			//$context .= ';""';
			$context .= ';';
		}
	}
	$filepath = 'player_profiles.csv';
	file_put_contents('../admin/temp/' . $filepath, $context);
	
	$response['filepath'] = 'editor_tab_import-export.php?file=' . $filepath;
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($response);
	exit;
}

/**
* Function to generate game cards file and return filepath to that as JSON.
* Needs $_POST['lang'].
* @return JSON response containing filepath to player profiles file.
*/
function generate_cards_file() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$lang = '';
	if (isset($_GET['lang'])) {
		$lang = $_GET['lang'];
	}
	
	$game;
	if (isset($_SESSION['admin']['game'])) {
		$game = $_SESSION['admin']['game'];
	}
	
	$response = array();
	$response['error'] = '';
	
	$db = DB::getInstance();
	$cards = $db->getAllCards($game['game_id'], $lang);
	
	$choices_max = 0;
	$results_max = array();
	
	$choice_count = 0;
	$result_count = 0;
	// Get card results and set maximum number of choices and results
	foreach ($cards as &$card) {
		$choice_count = count($card['choices']);
		if ($choice_count > $choices_max) {
			$choices_max = $choice_count;
		}
		$card['results'] = array();
		for ($i = 0; $i < count($card['choices']); $i++) {
			$card['results'][$i] = $db->getChoiceResults($card['choices'][$i]['choice_id'], $lang);
			$result_count = count($card['results'][$i]);
			if (!isset($results_max[$i]) || $result_count > $results_max[$i]) {
				$results_max[$i] = $result_count;
			}
		}
	}
	unset($card);
	
	// First line of csv
	$context = localize('ADMIN_EDITOR_CARD_COMMENT') . ';' . 'ID;' . localize('REPETITIVE') . ' (yes/no);';
	$context .= localize('ADMIN_EDITOR_CARD_NAME') . ';' . localize('ADMIN_EDITOR_CARD_DESCRIPTION') . ';' . localize('ADMIN_EDITOR_CARD_TAGS') . ';';
	$context .= localize('ADMIN_EDITOR_CARD_STAT_REQUIREMENTS') . ';' . localize('ADMIN_EDITOR_CARD_EXPERT_ADVICE') . ';';
	$context .= localize('ADMIN_EDITOR_CARD_PICTURE_LINK') . ';Layout;' . localize('ADMIN_EDITOR_EXPORT_CARDS_CHOICES_NBR');
	
	for ($i = 0; $i < $choices_max; $i++) {
		$context .= ';' . localize('CHOICE') . ' ' . ($i+1) . ';' . localize('ADMIN_EDITOR_EXPORT_CARDS_RESULTS_NBR') . ' ' . ($i+1);
		for ($j = 0; $j < $results_max[$i]; $j++) {
			$context .=  ';' . localize('PERCENT') . ' ' . ($i+1) . '.' . ($j+1) . ';' . localize('APP_SIMULATION_RESULT') . ' ' . ($i+1) . '.' . ($j+1) . ';';
			$context .= localize('ADMIN_EDITOR_CARD_STAT_CHANGES') . ' ' . ($i+1) . '.' . ($j+1) . ';' . localize('ADMIN_EDITOR_CARD_NEXT_CRITERIA') . ' ' . ($i+1) . '.' . ($j+1);
		}
	}
	
 	// Second line of csv
	$context .= PHP_EOL . localize('ADMIN_EDITOR_EXPORT_CARDS_COMMENT_LINE') . ';---;---;---;---;---;---;---;---;normal;---';
	for ($i = 0; $i < $choices_max; $i++) {
		$context .= ';---;---';
		for ($j = 0; $j < $results_max[$i]; $j++) {
			$context .=  ';---;---;---;---';
		}
	}
	$context .= PHP_EOL;
	
	foreach ($cards as $card) {
		
		$context .= $card['comment'] . ';';
		$context .= $card['card_external_id'] . ';';
		if ($card['repetitive']) {
			$context .= 'yes;';
		}
		else {
			$context .= 'no;';
		}
		if (!empty($card['card_name'])) {
			$context .= $card['card_name'] . ';';
		}
		else {
			$context .= $card['default_name'] . ';';
		}
		if (!empty($card['description'])) {
			$context .= $card['description'] . ';';
		}
		else {
			$context .= $card['default_description'] . ';';
		}
		$tags = '';
		if (!empty($card['tags'])) {
			$tags .= '#';
			$tags .= implode(' #', $card['tags']);
		}
		$context .= $tags . ';';
		$context .= implode(' ', $card['stat_requirements']) . ';';
		if (!empty($card['expert_advice'])) {
			$context .= $card['expert_advice'] . ';';
		}
		else {
			$context .= $card['default_expert_advice'] . ';';
		}
		$context .= $card['attachment'] . ';';
		$context .= $card['layout'] . ';';
		$context .= count($card['choices']);
		
		for ($i = 0; $i < $choices_max; $i++) {
			$context .= ';';
			if (isset($card['choices'][$i])) {
				if (!empty($card['choices'][$i]['choice_text'])) {
					$context .= $card['choices'][$i]['choice_text'];
				}
				else {
					$context .= $card['choices'][$i]['default_text'];
				}
				$context .= ';' . count($card['results'][$i]);
			}
			else {
				$context .= ';';
			}
			
			for ($j = 0; $j < $results_max[$i]; $j++) {
				$context .= ';';
				if (isset($card['results'][$i][$j])) {
					
					$context .= $card['results'][$i][$j]['weight'] . ';';
					if (!empty($card['results'][$i][$j]['result_text'])) {
						$context .= $card['results'][$i][$j]['result_text'] . ';';
					}
					else {
						$context .= $card['results'][$i][$j]['default_text'] . ';';
					}
					$context .= $card['results'][$i][$j]['stat_changes'] . ';';
					$context .= $card['results'][$i][$j]['next_criteria'];
				}
				else {
					$context .= ';;;';
				}
			}
		}
		$context .= PHP_EOL;
	}
	
	$filepath = 'cards.csv';
	file_put_contents('../admin/temp/' . $filepath, $context);
	
	$response['filepath'] = 'editor_tab_import-export.php?file=' . $filepath;
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($response);
	exit;
}

/**
* Function to replace stat tags in string with corresponding values and return formatted string as JSON.
* Needs $_GET['profile_id'] and $_GET['text'].
* @return JSON response containing modified_text.
*/
function replace_stat_tags() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$profile_id = 0;
	if (isset($_GET['profile_id'])) {
		$profile_id = doubleval($_GET['profile_id']);
	}
	$stats = get_profile_stats($profile_id);
	
	$text = '';
	if (isset($_GET['text'])) {
		$text = $_GET['text'];
	}
	
	// Replace stat based tags
	$modified_text = generate_dynamic_text($text, $stats);
	// Replace player name tag
	$modified_text = replace_player_name($modified_text, $profile_id);
	
	$response = array();
	$response['orig_text'] = $text;
	$response['modified_text'] = $modified_text;
	$response['stats'] = $stats;
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($response);
	exit;
}

/**
* Function to get stats related to player profile.
* @param double $profile_id Id of a profile to which stats to retrieve
* @return array Player stats
*/
function get_profile_stats($profile_id) {
	
	$db = DB::getInstance();
	$played_cards = $db->getPlayedCards($profile_id);
	$stats = array();
	
	$profile = $db->getProfile($profile_id);
	//$stats['current_scenario'] = '=' . $profile['scenario'];
	
	$scenario = 'bau';
	
	switch ($profile['scenario']) {
		case  1:
			$scenario = 'bau';
			break;
		case 2:
			$scenario = 'tec';
			break;
		case 3:
			$scenario = 'fre';
			break;
		case 4:
			$scenario = 'dgd';
			break;
		case 5:
			$scenario = 'oys';
			break;
		default:
			$scenario = 'bau';
			break;
	}
//	$stats['skenaario'] = '=' . $scenario;
	$stats['skenaario'] = '=' . 'bau';
/*	
	@skenaario=bau (Business as usual)
	@skenaario=tec (tehcno feelings)
	@skenaario=fre (Freelander)
	@skenaario=dgd (doing good, doing well)
	@skenaario=oys (My Block is my oyster)
*/
	foreach($played_cards as $card) {
		
		if ($card['choice_id'] > 0) {
		
			$result = $db->getResult($card['result_id']);
			if (!empty($result)) {
			
				$data_array = explode('@', $result['stat_changes']);
			
				foreach ($data_array as $stat) {
				
					$parsed_stat = GameEngine::parseStat($stat);
			
					if ($parsed_stat != false) {
					
						// If stat already exists
						if (isset($stats[$parsed_stat['key']])) {
							switch ($parsed_stat['operator']) {
								case '=':
									$stats[$parsed_stat['key']] = $parsed_stat['operator'] . $parsed_stat['value'];
									break;
								case '+':
									$number = doubleval($stats[$parsed_stat['key']]);
									$number = $number + doubleval($parsed_stat['value']);
									$stats[$parsed_stat['key']] = $number;
									break;
								case '-':
									$number = doubleval($stats[$parsed_stat['key']]);
									$number = $number - doubleval($parsed_stat['value']);
									$stats[$parsed_stat['key']] = $number;
									break;
								default:
									break;
							}
						}
							else {
							if ($parsed_stat['operator'] === '=') {
								$stats[$parsed_stat['key']] = $parsed_stat['operator'] . $parsed_stat['value'];
							}
							else {
								//$stats[$parsed_stat['key']] = $parsed_stat['value'];
								// Check if stat operator is minus
								if ($parsed_stat['operator'] === '-') {
									$stats[$parsed_stat['key']] = -1 * $parsed_stat['value'];
								}
								else {
									$stats[$parsed_stat['key']] = $parsed_stat['value'];
								}
							}
						}		
					}
				}
			}
		}
	}
	return $stats;
}

function createGlobeImage() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	$profile_id = 0;
	if (isset($_POST['profile_id'])) {
		$profile_id = doubleval($_POST['profile_id']);
	}
	
	$response = array();
	//$response['image_url'] = $url . '/uploads/' . $filename;
	$response['filename'] = '';
	
	if (isset($_POST['image_data'])) {

		//Get the base-64 string from data
		$filteredData = substr($_POST['image_data'], strpos($_POST['image_data'], ",") + 1);
	 
		//Decode the string
		$unencodedData = base64_decode($filteredData);
	 
		$filename = 'globe_' . $profile_id . '.png';

		//Save the image
		file_put_contents('../app/globe_images/' . $filename, $unencodedData);
		//$url = $_SERVER['HTTP_HOST'] . dirname($_SERVER['PHP_SELF']);

		$response = array();
		//$response['image_url'] = $url . '/uploads/' . $filename;
		$response['filename'] = $filename;
		//$response['filepath'] = 'uploads/' . $filename;
	}
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($response);
	exit();
}

/**
 * Function to keep session active.
 */
function updateSession() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$response = array();
	if (isset($_SESSION['user'])) {
		$response['user'] = $_SESSION['user'];
	}
	if (isset($_SESSION['isLogged'])) {
		$response['isLogged'] = $_SESSION['isLogged'];
	}
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($response);
	exit();	
}

function createNewAdmin() {
	
	if (isset($_SESSION['active']) && !$_SESSION['active']) {
		session_expired();
	}
	
	$game;
	if (isset($_SESSION['admin']['game'])) {
		$game = $_SESSION['admin']['game'];
	}
	
	$response = array();
	$response['user'] = array();
	//$response['error'] = '';
	
	$error = false;
	/** FormHandler $form_handler For validating and sanitizing the data. */
	$form_handler = new FormHandler();
	
	if (isset($game['game_id']) && isset($_POST['name'])) {
		
		$data = $form_handler->SanitizeString($_POST['name'], USERNAME_MAX_LENGTH, false, USERNAME_MIN_LENGTH);
			
			if (!$data) {
				$error = true;
				$response['error'] = $form_handler->_latest_error;
			}
			else {
				$response['user']['username'] = $data;
			}
	}
	else {
		$error = true;
	}
	if (!$error && isset($_POST['password1'])) {
			
		$data = $form_handler->SanitizeString($_POST['password1'], PASSWORD_MAX_LENGTH, false, PASSWORD_MIN_LENGTH);
			
		if (!$data) {
			$error = true;
			$response['error'] = $form_handler->_latest_error;
		}
		else {
			$response['user']['password1'] = $data;
		}
	}
	else {
		$error = true;
	}
	if (!$error && isset($_POST['password2'])) {
			
		$data = $form_handler->SanitizeString($_POST['password2'], PASSWORD_MAX_LENGTH, false, PASSWORD_MIN_LENGTH);
			
		if (!$data) {
			$error = true;
			$response['error'] = $form_handler->_latest_error;
		}
		else {
			$response['user']['password2'] = $data;
		}
	}
	else {
		$error = true;
	}
	if (!$error && isset($response['user']['password1']) && isset($response['user']['password2'])) {
			
		if ($response['user']['password1'] !== $response['user']['password2']) {
			$error = true;
			$response['error'] = localize('ERROR_FORM_HANDLER_PASSWORD_MATCH');
		}
	}
	else {
		$error = true;
	}
	// If form is valid
	if (!$error) {
		if (isset($response['user']['username']) && isset($response['user']['password1'])) {
				
			$db = DB::getInstance();
			// Create user
			$user_id = $db->createUser($response['user']['username'], $response['user']['password1']);

			if ($user_id > 0) {
				unset($response['user']['password1']);
				unset($response['user']['password2']);
				$response['user']['user_id'] = $user_id;
				// Add admin
				$db->addAdmin($user_id, $game['game_id']);
				$response['notification'] = localize('APP_INDEX_NOTIFICATION_NEW_USER_CREATED');
			}
			else {
				if ($user_id == -1) {
					$response['error'] = localize('ERROR_USER_EXISTS');
				}
			}
		}
	}
	
	header('Cache-Control: no-cache, must-revalidate'); // HTTP/1.1
	header('Expires: Sat, 26 Jul 1997 05:00:00 GMT'); // Date in the past
	header('Content-Type: application/json; charset=utf-8');
	echo json_encode($response);
	exit();
}

?>